<?php

/*-----------------------------------------------------------------------------------*/
/*	Custom function for pagination
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'max_pagination' ) ):
	function max_pagination($pages = '', $range = 4)
	{
		 $showitems = ($range * 2)+1; 
	 
		 global $paged;
		 if(empty($paged)) $paged = 1;
	 
		 if($pages == '')
		 {
			 global $wp_query;
			 $pages = $wp_query->max_num_pages;
			 if(!$pages)
			 {
				 $pages = 1;
			 }
		 }  
	 
		 if(1 != $pages)
		 {
			 echo "<div class=\"clearfix pagination\"><span>".__('Page')." ".$paged." ".__('of')." ".$pages."</span>";
			 if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>&laquo; ".__('Next')."</a>";
			 if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo; ".__('Previous')."</a>";
	 
			 for ($i=1; $i <= $pages; $i++)
			 {
				 if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
				 {
					 echo ($paged == $i)? "<span class=\"current\">".$i."</span>":"<a href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a>";
				 }
			 }
	 
			 if ($paged < $pages && $showitems < $pages) echo "<a href=\"".get_pagenum_link($paged + 1)."\">".__('Next')." &rsaquo;</a>";
			 if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>".__('Last')." &raquo;</a>";
			 echo "</div>\n";
		 }
	}
endif;

if ( ! function_exists( 'max_comment' ) ) :

/*-----------------------------------------------------------------------------------*/
/*	Template for comments and pingbacks.
/*-----------------------------------------------------------------------------------*/

function max_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 40 ); ?>
			<?php printf( __( '<span class="says">by</span> %s'), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- .comment-author .vcard -->

		<div class="comment-meta commentmetadata">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s'), get_comment_date(),  get_comment_time() ); ?>  <?php edit_comment_link( __( '(Edit)'), ' ' );
			?>
		</div><!-- .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
		break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:','invictus' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

/*-----------------------------------------------------------------------------------*/
/*	Get image cropping direction
/*-----------------------------------------------------------------------------------*/

function get_cropping_direction($meta_value) {	
	
	switch($meta_value){
		
		case 'Position in the Center (default)' :
			$dir = 'c';
		break;
	
		case 'Align top' :
			$dir = 't';
		break;
		
		case 'Align top right':
			$dir = 'tr';
		break;
		
		case 'Align top left':
			$dir = 'tl';
		break;
		
		case 'Align bottom':
			$dir = 'b';
		break;
		
		case 'Align bottom right':
			$dir = 'br';
		break;
		
		case 'Align bottom left':
			$dir = 'bl';
		break;
		
		case 'Align left':
			$dir = 'l';
		break;
		
		case 'Align right':
			$dir = 'r';
		break;
		
		default:
			$dir = 'c';
		break;
		
	}
	
	return $dir;
	
}

/*-----------------------------------------------------------------------------------*/
/*	Get hex to rgb and rgb to hex
/*-----------------------------------------------------------------------------------*/

	function max_HexToRGB($hex, $alpha = false) {
		$hex = ereg_replace("#", "", $hex);
		$color = array();
		
		if(strlen($hex) == 3) {
			$color['r'] = hexdec(substr($hex, 0, 1) . $r);
			$color['g'] = hexdec(substr($hex, 1, 1) . $g);
			$color['b'] = hexdec(substr($hex, 2, 1) . $b);
		}
		else if(strlen($hex) == 6) {
			$color['r'] = hexdec(substr($hex, 0, 2));
			$color['g'] = hexdec(substr($hex, 2, 2));
			$color['b'] = hexdec(substr($hex, 4, 2));
		}

		if($alpha){
			$color['a'] = $alpha;
		}
		
		return $color;
	}
	
	
	function max_RGBToHex($r, $g, $b) {
		//String padding bug found and the solution put forth by Pete Williams (http://snipplr.com/users/PeteW)
		$hex = "#";
		$hex.= str_pad(dechex($r), 2, "0", STR_PAD_LEFT);
		$hex.= str_pad(dechex($g), 2, "0", STR_PAD_LEFT);
		$hex.= str_pad(dechex($b), 2, "0", STR_PAD_LEFT);
		
		return $hex;
	}

/*-----------------------------------------------------------------------------------*/
/*	Google Font Lib
/*-----------------------------------------------------------------------------------*/

function max_get_google_font( $max_option ) {
	echo '
	
	<!-- Google Fonts -->
	';
	
	// Arial Standard
	if ($max_option == 'Arial, Helvetica, sans-serif') { }
	
	// Verdana Standard
	if ($max_option == 'Verdana, Geneva, sans-serif') { }
	
	// Tahoma Standard
	if ($max_option == 'Tahoma, Geneva, sans-serif') { }	

	// Tahoma Standard
	if ($max_option == 'Georgia, Times, serif') { }
	
	// Allan
	if ($max_option == 'Allan') { echo '<link href=\'http://fonts.googleapis.com/css?family=Allan:bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Allerta
	if ($max_option == 'Allerta') { echo '<link href=\'http://fonts.googleapis.com/css?family=Allerta\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Allerta Stencil
	if ($max_option == 'Allerta Stencil') { echo '<link href=\'http://fonts.googleapis.com/css?family=Allerta+Stencil\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Amaranth
	if ($max_option == 'Amaranth') { echo '<link href=\'http://fonts.googleapis.com/css?family=Amaranth\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Anton
	if ($max_option == 'Anton') { echo '<link href=\'http://fonts.googleapis.com/css?family=Anton\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Anonymous Pro
	if ($max_option == 'Anonymous Pro') { echo '<link href=\'http://fonts.googleapis.com/css?family=Anonymous+Pro:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Architects Daughter
	if ($max_option == 'Architects Daughter') { echo '<link href=\'http://fonts.googleapis.com/css?family=Architects+Daughter\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Arimo
	if ($max_option == 'Arimo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Arimo:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Arvo	
	if ($max_option == 'Arvo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Arvo:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Astloch:regular,bold
	if ($max_option == 'Astloch') { echo '<link href=\'http://fonts.googleapis.com/css?family=Astloch:regular,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Bentham
	if ($max_option == 'Bentham') { echo '<link href=\'http://fonts.googleapis.com/css?family=Bentham\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Bevan
	if ($max_option == 'Bevan') { echo '<link href=\'http://fonts.googleapis.com/css?family=Bevan\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Buda Light
	if ($max_option == 'Buda') { echo '<link href=\'http://fonts.googleapis.com/css?family=Buda:light\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cabin:regular,500,600,bold
	if ($max_option == 'Cabin') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cabin:regular,500,600,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cabin+Sketch:bold
	if ($max_option == 'Cabin Sketch') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cabin+Sketch:bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Calligraffitti
	if ($max_option == 'Calligraffitti') { echo '<link href=\'http://fonts.googleapis.com/css?family=Calligraffitti\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Candal
	if ($max_option == 'Candal') { echo '<link href=\'http://fonts.googleapis.com/css?family=Candal\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cantarell
	
	if ($max_option == 'Cantarell') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cantarell:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cardo
	if ($max_option == 'Cardo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cardo\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cherry Cream Soda
	if ($max_option == 'Cherry Cream Soda') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cherry+Cream+Soda\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Chewy
	if ($max_option == 'Chewy') { echo '<link href=\'http://fonts.googleapis.com/css?family=Chewy\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Coda
	if ($max_option == 'Coda') { echo '<link href=\'http://fonts.googleapis.com/css?family=Coda:800\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Coming Soon
	if ($max_option == 'Coming Soon') { echo '<link href=\'http://fonts.googleapis.com/css?family=Coming+Soon\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Copse
	if ($max_option == 'Copse') { echo '<link href=\'http://fonts.googleapis.com/css?family=Copse\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Corben Bold
	if ($max_option == 'Corben:bold') { echo '<link href=\'http://fonts.googleapis.com/css?family=Corben:bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cousine
	if ($max_option == 'Cousine') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cousine:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Crafty Girls
	if ($max_option == 'Crafty Girls') { echo '<link href=\'http://fonts.googleapis.com/css?family=Crafty+Girls\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Crimson Text
	if ($max_option == 'Crimson Text') { echo '<link href=\'http://fonts.googleapis.com/css?family=Crimson+Text\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Crushed
	if ($max_option == 'Crushed') { echo '<link href=\'http://fonts.googleapis.com/css?family=Crushed\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Covered By Your Grace
	if ($max_option == 'Covered By Your Grace') { echo '<link href=\'http://fonts.googleapis.com/css?family=Covered+By+Your+Grace\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Cuprum
	if ($max_option == 'Cuprum') { echo '<link href=\'http://fonts.googleapis.com/css?family=Cuprum\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Dancing Script
	if ($max_option == 'Dancing Script') { echo '<link href=\'http://fonts.googleapis.com/css?family=Dancing+Script\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Droid Sans
	if ($max_option == 'Droid Sans') { echo '<link href=\'http://fonts.googleapis.com/css?family=Droid+Sans:regular,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Droid Sans Mono
	if ($max_option == 'Droid Sans Mono') { echo '<link href=\'http://fonts.googleapis.com/css?family=Droid+Sans+Mono\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Droid Serif
	if ($max_option == 'Droid Serif') { echo '<link href=\'http://fonts.googleapis.com/css?family=Droid Serif:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Expletus Sans:regular,500,600,bold
	if ($max_option == 'Expletus Sans') { echo '<link href=\'http://fonts.googleapis.com/css?family=Expletus+Sans:regular,500,600,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Fontdiner Swanky
	if ($max_option == 'Fontdiner Swanky') { echo '<link href=\'http://fonts.googleapis.com/css?family=Fontdiner+Swanky\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Geo
	if ($max_option == 'Geo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Geo\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Goudy Bookletter 1911
	if ($max_option == 'Goudy Bookletter 1911') { echo '<link href=\'http://fonts.googleapis.com/css?family=Goudy+Bookletter+1911\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Gruppo
	if ($max_option == 'Gruppo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Gruppo\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Homemade Apple
	if ($max_option == 'Homemade Apple') { echo '<link href=\'http://fonts.googleapis.com/css?family=Homemade+Apple\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Inconsolata
	if ($max_option == 'Inconsolata') { echo '<link href=\'http://fonts.googleapis.com/css?family=Inconsolata\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Indie Flower
	if ($max_option == 'Indie Flower') { echo '<link href=\'http://fonts.googleapis.com/css?family=Indie+Flower\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// IM Fell DW Pica
	if ($max_option == 'IM Fell DW Pica') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+DW+Pica:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell DW Pica SC') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+DW+Pica SC\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell Double Pica') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+Double+Pica:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell Double Pica SC') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+Double+Pica SC\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell English') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+English:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell English SC') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+English+SC\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell French Canon') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+French+Canon:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell French Canon SC') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+French+Canon SC\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell Great Primer') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+Great+Primer:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'IM Fell Great Primer SC') { echo '<link href=\'http://fonts.googleapis.com/css?family=IM+Fell+Great+Primer+SC\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Irish Grover
	if ($max_option == 'Irish Grover') { echo '<link href=\'http://fonts.googleapis.com/css?family=Irish+Grover\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Irish Growler
	if ($max_option == 'Irish Growler') { echo '<link href=\'http://fonts.googleapis.com/css?family=Irish+Growler\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Josefin Sans Regular
	if ($max_option == 'Josefin Sans') { echo '<link href=\'http://fonts.googleapis.com/css?family=Josefin+Sans:regular,regularitalic,600,600italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Just Another Hand
	if ($max_option == 'Just Another Hand') { echo '<link href=\'http://fonts.googleapis.com/css?family=Just+Another+Hand\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Just Me Again Down Here
	if ($max_option == 'Just Me Again Down Here') { echo '<link href=\'http://fonts.googleapis.com/css?family=Just+Me+Again+Down+Here\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Kenia
	if ($max_option == 'Kenia') { echo '<link href=\'http://fonts.googleapis.com/css?family=Kenia\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Kranky
	if ($max_option == 'Kranky') { echo '<link href=\'http://fonts.googleapis.com/css?family=Kranky\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Kreon
	if ($max_option == 'Kreon') { echo '<link href=\'http://fonts.googleapis.com/css?family=Kreon:light,regular,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Kristi
	if ($max_option == 'Kristi') { echo '<link href=\'http://fonts.googleapis.com/css?family=Kristi\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Lato Regular plus italic
	if ($max_option == 'Lato') { echo '<link href=\'http://fonts.googleapis.com/css?family=Lato:regular,regularitalic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// League Script
	if ($max_option == 'League Script') { echo '<link href=\'http://fonts.googleapis.com/css?family=League+Script\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Lekton bold, italic, bold italic
	if ($max_option == 'Lekton') { echo '<link href=\'http://fonts.googleapis.com/css?family=Lekton:regular,italic,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Lobster
	if ($max_option == 'Lobster') { echo '<link href=\'http://fonts.googleapis.com/css?family=Lobster\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Luckiest Guy
	if ($max_option == 'Luckiest Guy') { echo '<link href=\'http://fonts.googleapis.com/css?family=Luckiest+Guy\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Maiden Orange
	if ($max_option == 'Maiden Orange') { echo '<link href=\'http://fonts.googleapis.com/css?family=Maiden+Orange\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Meddon
	if ($max_option == 'Meddon') { echo '<link href=\'http://fonts.googleapis.com/css?family=Meddon\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// MedievalSharp
	if ($max_option == 'MedievalSharp') { echo '<link href=\'http://fonts.googleapis.com/css?family=MedievalSharp\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Merriweather
	if ($max_option == 'Merriweather') { echo '<link href=\'http://fonts.googleapis.com/css?family=Merriweather\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Molengo
	if ($max_option == 'Molengo') { echo '<link href=\'http://fonts.googleapis.com/css?family=Molengo\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Mountains of Christmas
	if ($max_option == 'Mountains of Christmas') { echo '<link href=\'http://fonts.googleapis.com/css?family=Mountains+of+Christmas\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Neucha
	if ($max_option == 'Neucha') { echo '<link href=\'http://fonts.googleapis.com/css?family=Neucha\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Neuton
	if ($max_option == 'Neuton') { echo '<link href=\'http://fonts.googleapis.com/css?family=Neuton\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Nobile
	if ($max_option == 'Nobile') { echo '<link href=\'http://fonts.googleapis.com/css?family=Nobile:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// OFL Sorts Mill Goudy TT
	if ($max_option == 'OFL Sorts Mill Goudy TT') { echo '<link href=\'http://fonts.googleapis.com/css?family=OFL Sorts Mill Goudy TT:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Old Standard
	if ($max_option == 'Old Standard TT') { echo '<link href=\'http://fonts.googleapis.com/css?family=Old Standard TT:regular,italic,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Orbitron 500
	if ($max_option == 'Orbitron') { echo '<link href=\'http://fonts.googleapis.com/css?family=Orbitron:500,bold,900\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Pacifico
	if ($max_option == 'Pacifico') { echo '<link href=\'http://fonts.googleapis.com/css?family=Pacifico\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Permanent Marker
	if ($max_option == 'Permanent Marker') { echo '<link href=\'http://fonts.googleapis.com/css?family=Permanent+Marker\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Philosopher
	if ($max_option == 'Philosopher') { echo '<link href=\'http://fonts.googleapis.com/css?family=Philosopher\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// PT Sans
	if ($max_option == 'PT Sans') { echo '<link href=\'http://fonts.googleapis.com/css?family=PT+Sans:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'PT Sans Caption') { echo '<link href=\'http://fonts.googleapis.com/css?family=PT+Sans+Caption:Bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	if ($max_option == 'PT Sans Narrow') { echo '<link href=\'http://fonts.googleapis.com/css?family=PT+Sans+Narrow:Bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// PT Serif:regular,italic,bold,bolditalic
	if ($max_option == 'PT Serif') { echo '<link href=\'http://fonts.googleapis.com/css?family=PT+Serif:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// PT Serif Caption:regular,italic
	if ($max_option == 'PT Serif Caption') { echo '<link href=\'http://fonts.googleapis.com/css?family=PT+Serif+Caption:regular,italic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Puritan
	if ($max_option == 'Puritan') { echo '<link href=\'http://fonts.googleapis.com/css?family=Puritan:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Quattrocento
	if ($max_option == 'Quattrocento') { echo '<link href=\'http://fonts.googleapis.com/css?family=Quattrocento\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Radley
	if ($max_option == 'Radley') { echo '<link href=\'http://fonts.googleapis.com/css?family=Radley\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Raleway
	if ($max_option == 'Raleway') { echo '<link href=\'http://fonts.googleapis.com/css?family=Raleway:100\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Reenie Beanie
	if ($max_option == 'Reenie Beanie') { echo '<link href=\'http://fonts.googleapis.com/css?family=Reenie+Beanie\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Rock Salt
	if ($max_option == 'Rock Salt') { echo '<link href=\'http://fonts.googleapis.com/css?family=Rock+Salt\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Schoolbell
	if ($max_option == 'Schoolbell') { echo '<link href=\'http://fonts.googleapis.com/css?family=Schoolbell\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Slackey
	if ($max_option == 'Slackey') { echo '<link href=\'http://fonts.googleapis.com/css?family=Slackey\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Sniglet
	if ($max_option == 'Sniglet') { echo '<link href=\'http://fonts.googleapis.com/css?family=Sniglet:800\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Sunshiney
	if ($max_option == 'Sunshiney') { echo '<link href=\'http://fonts.googleapis.com/css?family=Sunshiney\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Syncopate
	if ($max_option == 'Syncopate') { echo '<link href=\'http://fonts.googleapis.com/css?family=Syncopate\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Tangerine
	if ($max_option == 'Tangerine') { echo '<link href=\'http://fonts.googleapis.com/css?family=Tangerine\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Tinos	
	if ($max_option == 'Tinos') { echo '<link href=\'http://fonts.googleapis.com/css?family=Tinos:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Ubuntu
	if ($max_option == 'Ubuntu') { echo '<link href=\'http://fonts.googleapis.com/css?family=Ubuntu:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// UnifrakturCook
	if ($max_option == 'UnifrakturCook') { echo '<link href=\'http://fonts.googleapis.com/css?family=UnifrakturCook:bold\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// UnifrakturMaguntia
	if ($max_option == 'UnifrakturMaguntia') { echo '<link href=\'http://fonts.googleapis.com/css?family=UnifrakturMaguntia\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Unkempt
	if ($max_option == 'Unkempt') { echo '<link href=\'http://fonts.googleapis.com/css?family=Unkempt\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Vibur
	if ($max_option == 'Vibur') { echo '<link href=\'http://fonts.googleapis.com/css?family=Vibur\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Vollkorn
	if ($max_option == 'Vollkorn') { echo '<link href=\'http://fonts.googleapis.com/css?family=Vollkorn:regular,italic,bold,bolditalic\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// VT323
	if ($max_option == 'VT323') { echo '<link href=\'http://fonts.googleapis.com/css?family=VT323\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Walter Turncoat
	if ($max_option == 'Walter Turncoat') { echo '<link href=\'http://fonts.googleapis.com/css?family=Walter+Turncoat\' rel=\'stylesheet\' type=\'text/css\' />'; }
	
	// Yanone Kaffeesatz
	if ($max_option == 'Yanone Kaffeesatz') { echo '<link href=\'http://fonts.googleapis.com/css?family=Yanone+Kaffeesatz:extralight,light,regular,bold\' rel=\'stylesheet\' type=\'text/css\' />'; }

}

// Get Font Select
function max_google_font_select() { 
	echo '
		<optgroup label="Standard Fonts">
			<option value="Arial, Helvetica, sans-serif">Arial, Helvetica, sans-serif</option>
			<option value="Verdana, Geneva, sans-serif">Verdana, Geneva, sans-serif</option>
			<option value="Tahoma, Geneva, sans-serif">Tahoma, Geneva, sans-serif</option>
			<option value="Georgia, Times, serif">Georgia, Times, serif</option>
		</optgroup>			
		<optgroup label="Google API Fonts">
			<option value="Allan">Allan</option>
			<option value="Anonymous Pro">Anonymous Pro (plus italic, bold and bold italic)</option>
			<option value="Allerta Stencil">Allerta Stencil</option>
			<option value="Allerta">Allerta</option>
			<option value="Amaranth">Amaranth</option>
			<option value="Anton">Anton</option>
			<option value="Architects Daughter">Architects Daughter</option>
			<option value="Arimo">Arimo (plus italic, bold and bold italic)</option>
			<option value="Arvo">Arvo (plus italic, bold and bold italic)</option>
			<option value="Astloch">Astloch (plus bold)</option>
			<option value="Bentham">Bentham</option>
			<option value="Bevan">Bevan</option>
			<option value="Buda">Buda</option>
			<option value="Cabin">Cabin (plus 500, 600, and bold)</option>
			<option value="Cabin Sketch">Cabin Sketch</option>
			<option value="Calligraffitti">Calligraffitti</option>
			<option value="Candal">Candal</option>
			<option value="Cantarell">Cantarell (plus italic, bold and bold italic)</option>
			<option value="Cardo">Cardo</option>
			<option value="Cherry Cream Soda">Cherry Cream Soda</option>
			<option value="Chewy">Chewy</option>
			<option value="Coda">Coda</option>
			<option value="Coming Soon">Coming Soon</option>
			<option value="Copse">Copse</option>
			<option value="Corben">Corben</option>
			<option value="Cousine">Cousine (plus italic, bold and bold italic)</option>
			<option value="Covered By Your Grace">Covered By Your Grace</option>
			<option value="Crafty Girls">Crafty Girls</option>
			<option value="Crimson Text">Crimson Text</option>
			<option value="Crushed">Crushed</option>
			<option value="Cuprum">Cuprum</option>
			<option value="Dancing Script">Dancing Script</option>
			<option value="Droid Sans">Droid Sans (plus bold)</option>
			<option value="Droid Sans Mono">Droid Sans Mono</option>
			<option value="Droid Serif">Droid Serif (plus italic, bold and bold italic)</option>
			<option value="Expletus Sans">Expletus Sans (plus 500, 600, and bold)</option>
			<option value="Fontdiner Swanky">Fontdiner Swanky</option>
			<option value="Geo">Geo</option>
			<option value="Goudy Bookletter 1911">Goudy Bookletter 1911</option>
			<option value="Gruppo">Gruppo</option>
			<option value="Homemade Apple">Homemade Apple</option>
			<option value="Inconsolata">Inconsolata</option>
			<option value="Indie Flower">Indie Flower</option>
			<option value="IM Fell DW Pica">IM Fell DW Pica (plus italic)</option>
			<option value="IM Fell DW Pica SC">IM Fell DW Pica SC</option>
			<option value="IM Fell Double Pica">IM Fell Double Pica (plus italic)</option>
			<option value="IM Fell Double Pica SC">IM Fell Double Pica SC</option>
			<option value="IM Fell English">IM Fell English (plus italic)</option>
			<option value="IM Fell English SC">IM Fell English SC</option>
			<option value="IM Fell French Canon">IM Fell French Canon (plus italic)</option>
			<option value="IM Fell French Canon SC">IM Fell French Canon SC</option>
			<option value="IM Fell Great Primer">IM Fell Great Primer (plus italic)</option>
			<option value="IM Fell Great Primer SC">IM Fell Great Primer SC</option>
			<option value="Irish Grover">Irish Grover</option>
			<option value="Irish Growler">Irish Growler</option>
			<option value="Josefin Sans">Josefin Sans (plus italic, 600 ,600 italic, bold, bold italic)</option>
			<option value="Just Another Hand">Just Another Hand</option>
			<option value="Just Me Again Down Here">Just Me Again Down Here</option>
			<option value="Kenia">Kenia</option>
			<option value="Kranky">Kranky</option>
			<option value="Kreon">Kreon (plus light and bold)</option>
			<option value="Kristi">Kristi</option>
			<option value="Lato">Lato (plus italic, bold, bold italic)</option>
			<option value="League Script">League Script</option>
			<option value="Lekton">Lekton (plus italic and bold)</option>
			<option value="Lobster">Lobster</option>
			<option value="Luckiest Guy">Luckiest Guy</option>
			<option value="Maiden Orange">Maiden Orange</option>
			<option value="Meddon">Meddon</option>
			<option value="MedievalSharp">MedievalSharp</option>
			<option value="Merriweather">Merriweather</option>
			<option value="Molengo">Molengo</option>
			<option value="Mountains of Christmas">Mountains of Christmas</option>
			<option value="Nobile">Nobile (plus italic, bold and bold italic)</option>
			<option value="Neucha">Neucha</option>
			<option value="Neuton">Neuton</option>
			<option value="OFL Sorts Mill Goudy TT">OFL Sorts Mill Goudy TT (plus italic)</option>
			<option value="Old Standard TT">Old Standard TT (plus italic and bold)</option>
			<option value="Orbitron">Orbitron (500, bold, 900)</option>
			<option value="Reenie Beanie">Reenie Beanie</option>
			<option value="Pacifico">Pacifico</option>
			<option value="Permanent Marker">Permanent Marker</option>
			<option value="Philosopher">Philosopher</option>
			<option value="PT Sans">PT Sans (plus italic, bold and bold italic)</option>
			<option value="PT Sans Caption">PT Sans Caption (plus bold)</option>
			<option value="PT Sans Narrow">PT Sans Narrow (plus bold)</option>
			<option value="PT Serif">PT Serif (plus italic, bold and bold italic)</option>
			<option value="PT Serif Caption">PT Serif Caption (plus italic)</option>
			<option value="Puritan">Puritan (plus italic, bold and bold italic)</option>
			<option value="Quattrocento">Quattrocento</option>
			<option value="Radley">Radley</option>
			<option value="Raleway">Raleway</option>
			<option value="Rock Salt">Rock Salt</option>
			<option value="Schoolbell">Schoolbell</option>
			<option value="Slackey">Slackey</option>
			<option value="Sniglet>Sniglet</option>
			<option value="Sunshiney">Sunshiney</option>
			<option value="Syncopate">Syncopate</option>
			<option value="Tangerine">Tangerine</option>
			<option value="Tinos">Tinos (plus italic, bold and bold italic)</option>
			<option value="Ubuntu">Ubuntu (plus italic, bold and bold italic)</option>
			<option value="Unkempt">Unkempt</option>
			<option value="UnifrakturCook>UnifrakturCook</option>
			<option value="UnifrakturMaguntia">UnifrakturMaguntia</option>
			<option value="Vibur">Vibur</option>
			<option value="Vollkorn">Vollkorn (plus italic, bold and bold italic)</option>
			<option value="VT323">VT323</option>
			<option value="Walter Turncoat">Walter Turncoat</option>
			<option value="Yanone Kaffeesatz">Yanone Kaffeesatz (plus 300,400,700)</option>
		</optgroup>
	';
}

?>