<?php

/**
 * @package WordPress
 * @subpackage Default_Theme
 */

automatic_feed_links();

if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
}

/** @ignore */
function kubrick_head() {
	$head = "<style type='text/css'>\n<!--";
	$output = '';
	if ( kubrick_header_image() ) {
		$url =  kubrick_header_image_url() ;
		$output .= "#header { background: url('$url') no-repeat bottom center; }\n";
	}
	if ( false !== ( $color = kubrick_header_color() ) ) {
		$output .= "#headerimg h1 a, #headerimg h1 a:visited, #headerimg .description { color: $color; }\n";
	}
	if ( false !== ( $display = kubrick_header_display() ) ) {
		$output .= "#headerimg { display: $display }\n";
	}
	$foot = "--></style>\n";
	if ( '' != $output )
		echo $head . $output . $foot;
}

add_action('wp_head', 'kubrick_head');

function kubrick_header_image() {
	return apply_filters('kubrick_header_image', get_option('kubrick_header_image'));
}

function kubrick_upper_color() {
	if (strpos($url = kubrick_header_image_url(), 'header-img.php?') !== false) {
		parse_str(substr($url, strpos($url, '?') + 1), $q);
		return $q['upper'];
	} else
		return '69aee7';
}

function kubrick_lower_color() {
	if (strpos($url = kubrick_header_image_url(), 'header-img.php?') !== false) {
		parse_str(substr($url, strpos($url, '?') + 1), $q);
		return $q['lower'];
	} else
		return '4180b6';
}

function kubrick_header_image_url() {
	if ( $image = kubrick_header_image() )
		$url = get_template_directory_uri() . '/images/' . $image;
	else
		$url = get_template_directory_uri() . '/images/kubrickheader.jpg';

	return $url;
}

function kubrick_header_color() {
	return apply_filters('kubrick_header_color', get_option('kubrick_header_color'));
}

function kubrick_header_color_string() {
	$color = kubrick_header_color();
	if ( false === $color )
		return 'white';

	return $color;
}

function kubrick_header_display() {
	return apply_filters('kubrick_header_display', get_option('kubrick_header_display'));
}

function kubrick_header_display_string() {
	$display = kubrick_header_display();
	return $display ? $display : 'inline';
}

add_action('admin_menu', 'kubrick_add_theme_page');

function kubrick_add_theme_page() {
	if ( isset( $_GET['page'] ) && $_GET['page'] == basename(__FILE__) ) {
		if ( isset( $_REQUEST['action'] ) && 'save' == $_REQUEST['action'] ) {
			check_admin_referer('kubrick-header');
			if ( isset($_REQUEST['njform']) ) {
				if ( isset($_REQUEST['defaults']) ) {
					delete_option('kubrick_header_image');
					delete_option('kubrick_header_color');
					delete_option('kubrick_header_display');
				} else {
					if ( '' == $_REQUEST['njfontcolor'] )
						delete_option('kubrick_header_color');
					else {
						$fontcolor = preg_replace('/^.*(#[0-9a-fA-F]{6})?.*$/', '$1', $_REQUEST['njfontcolor']);
						update_option('kubrick_header_color', $fontcolor);
					}
					if ( preg_match('/[0-9A-F]{6}|[0-9A-F]{3}/i', $_REQUEST['njuppercolor'], $uc) && preg_match('/[0-9A-F]{6}|[0-9A-F]{3}/i', $_REQUEST['njlowercolor'], $lc) ) {
						$uc = ( strlen($uc[0]) == 3 ) ? $uc[0]{0}.$uc[0]{0}.$uc[0]{1}.$uc[0]{1}.$uc[0]{2}.$uc[0]{2} : $uc[0];
						$lc = ( strlen($lc[0]) == 3 ) ? $lc[0]{0}.$lc[0]{0}.$lc[0]{1}.$lc[0]{1}.$lc[0]{2}.$lc[0]{2} : $lc[0];
						update_option('kubrick_header_image', "header-img.php?upper=$uc&lower=$lc");
					}

					if ( isset($_REQUEST['toggledisplay']) ) {
						if ( false === get_option('kubrick_header_display') )
							update_option('kubrick_header_display', 'none');
						else
							delete_option('kubrick_header_display');
					}
				}
			} else {

				if ( isset($_REQUEST['headerimage']) ) {
					check_admin_referer('kubrick-header');
					if ( '' == $_REQUEST['headerimage'] )
						delete_option('kubrick_header_image');
					else {
						$headerimage = preg_replace('/^.*?(header-img.php\?upper=[0-9a-fA-F]{6}&lower=[0-9a-fA-F]{6})?.*$/', '$1', $_REQUEST['headerimage']);
						update_option('kubrick_header_image', $headerimage);
					}
				}

				if ( isset($_REQUEST['fontcolor']) ) {
					check_admin_referer('kubrick-header');
					if ( '' == $_REQUEST['fontcolor'] )
						delete_option('kubrick_header_color');
					else {
						$fontcolor = preg_replace('/^.*?(#[0-9a-fA-F]{6})?.*$/', '$1', $_REQUEST['fontcolor']);
						update_option('kubrick_header_color', $fontcolor);
					}
				}

				if ( isset($_REQUEST['fontdisplay']) ) {
					check_admin_referer('kubrick-header');
					if ( '' == $_REQUEST['fontdisplay'] || 'inline' == $_REQUEST['fontdisplay'] )
						delete_option('kubrick_header_display');
					else
						update_option('kubrick_header_display', 'none');
				}
			}
			//print_r($_REQUEST);
			wp_redirect("themes.php?page=functions.php&saved=true");
			die;
		}
		add_action('admin_head', 'kubrick_theme_page_head');
	}
	add_theme_page(__('Custom Header'), __('Custom Header'), 'edit_themes', basename(__FILE__), 'kubrick_theme_page');
}

function kubrick_theme_page_head() {
?>
<script type="text/javascript" src="../wp-includes/js/colorpicker.js"></script>
<script type='text/javascript'>
// <![CDATA[
	function pickColor(color) {
		ColorPicker_targetInput.value = color;
		kUpdate(ColorPicker_targetInput.id);
	}
	function PopupWindow_populate(contents) {
		contents += '<br /><p style="text-align:center;margin-top:0px;"><input type="button" class="button-secondary" value="<?php esc_attr_e('Close Color Picker'); ?>" onclick="cp.hidePopup(\'prettyplease\')"></input></p>';
		this.contents = contents;
		this.populated = false;
	}
	function PopupWindow_hidePopup(magicword) {
		if ( magicword != 'prettyplease' )
			return false;
		if (this.divName != null) {
			if (this.use_gebi) {
				document.getElementById(this.divName).style.visibility = "hidden";
			}
			else if (this.use_css) {
				document.all[this.divName].style.visibility = "hidden";
			}
			else if (this.use_layers) {
				document.layers[this.divName].visibility = "hidden";
			}
		}
		else {
			if (this.popupWindow && !this.popupWindow.closed) {
				this.popupWindow.close();
				this.popupWindow = null;
			}
		}
		return false;
	}
	function colorSelect(t,p) {
		if ( cp.p == p && document.getElementById(cp.divName).style.visibility != "hidden" )
			cp.hidePopup('prettyplease');
		else {
			cp.p = p;
			cp.select(t,p);
		}
	}
	function PopupWindow_setSize(width,height) {
		this.width = 162;
		this.height = 210;
	}

	var cp = new ColorPicker();
	function advUpdate(val, obj) {
		document.getElementById(obj).value = val;
		kUpdate(obj);
	}
	function kUpdate(oid) {
		if ( 'uppercolor' == oid || 'lowercolor' == oid ) {
			uc = document.getElementById('uppercolor').value.replace('#', '');
			lc = document.getElementById('lowercolor').value.replace('#', '');
			hi = document.getElementById('headerimage');
			hi.value = 'header-img.php?upper='+uc+'&lower='+lc;
			document.getElementById('header').style.background = 'url("<?php echo get_template_directory_uri(); ?>/images/'+hi.value+'") center no-repeat';
			document.getElementById('advuppercolor').value = '#'+uc;
			document.getElementById('advlowercolor').value = '#'+lc;
		}
		if ( 'fontcolor' == oid ) {
			document.getElementById('header').style.color = document.getElementById('fontcolor').value;
			document.getElementById('advfontcolor').value = document.getElementById('fontcolor').value;
		}
		if ( 'fontdisplay' == oid ) {
			document.getElementById('headerimg').style.display = document.getElementById('fontdisplay').value;
		}
	}
	function toggleDisplay() {
		td = document.getElementById('fontdisplay');
		td.value = ( td.value == 'none' ) ? 'inline' : 'none';
		kUpdate('fontdisplay');
	}
	function toggleAdvanced() {
		a = document.getElementById('jsAdvanced');
		if ( a.style.display == 'none' )
			a.style.display = 'block';
		else
			a.style.display = 'none';
	}
	function kDefaults() {
		document.getElementById('headerimage').value = '';
		document.getElementById('advuppercolor').value = document.getElementById('uppercolor').value = '#69aee7';
		document.getElementById('advlowercolor').value = document.getElementById('lowercolor').value = '#4180b6';
		document.getElementById('header').style.background = 'url("<?php echo get_template_directory_uri(); ?>/images/kubrickheader.jpg") center no-repeat';
		document.getElementById('header').style.color = '#FFFFFF';
		document.getElementById('advfontcolor').value = document.getElementById('fontcolor').value = '';
		document.getElementById('fontdisplay').value = 'inline';
		document.getElementById('headerimg').style.display = document.getElementById('fontdisplay').value;
	}
	function kRevert() {
		document.getElementById('headerimage').value = '<?php echo esc_js(kubrick_header_image()); ?>';
		document.getElementById('advuppercolor').value = document.getElementById('uppercolor').value = '#<?php echo esc_js(kubrick_upper_color()); ?>';
		document.getElementById('advlowercolor').value = document.getElementById('lowercolor').value = '#<?php echo esc_js(kubrick_lower_color()); ?>';
		document.getElementById('header').style.background = 'url("<?php echo esc_js(kubrick_header_image_url()); ?>") center no-repeat';
		document.getElementById('header').style.color = '';
		document.getElementById('advfontcolor').value = document.getElementById('fontcolor').value = '<?php echo esc_js(kubrick_header_color_string()); ?>';
		document.getElementById('fontdisplay').value = '<?php echo esc_js(kubrick_header_display_string()); ?>';
		document.getElementById('headerimg').style.display = document.getElementById('fontdisplay').value;
	}
	function kInit() {
		document.getElementById('jsForm').style.display = 'block';
		document.getElementById('nonJsForm').style.display = 'none';
	}
	addLoadEvent(kInit);
// ]]>
</script>
<style type='text/css'>
	#headwrap {
		text-align: center;
	}
	#kubrick-header {
		font-size: 80%;
	}
	#kubrick-header .hibrowser {
		width: 780px;
		height: 260px;
		overflow: scroll;
	}
	#kubrick-header #hitarget {
		display: none;
	}
	#kubrick-header #header h1 {
		font-family: 'Trebuchet MS', 'Lucida Grande', Verdana, Arial, Sans-Serif;
		font-weight: bold;
		font-size: 4em;
		text-align: center;
		padding-top: 70px;
		margin: 0;
	}

	#kubrick-header #header .description {
		font-family: 'Lucida Grande', Verdana, Arial, Sans-Serif;
		font-size: 1.2em;
		text-align: center;
	}
	#kubrick-header #header {
		text-decoration: none;
		color: <?php echo kubrick_header_color_string(); ?>;
		padding: 0;
		margin: 0;
		height: 200px;
		text-align: center;
		background: url('<?php echo kubrick_header_image_url(); ?>') center no-repeat;
	}
	#kubrick-header #headerimg {
		margin: 0;
		height: 200px;
		width: 100%;
		display: <?php echo kubrick_header_display_string(); ?>;
	}
	#jsForm {
		display: none;
		text-align: center;
	}
	#jsForm input.submit, #jsForm input.button, #jsAdvanced input.button {
		padding: 0px;
		margin: 0px;
	}
	#advanced {
		text-align: center;
		width: 620px;
	}
	html>body #advanced {
		text-align: center;
		position: relative;
		left: 50%;
		margin-left: -380px;
	}
	#jsAdvanced {
		text-align: right;
	}
	#nonJsForm {
		position: relative;
		text-align: left;
		margin-left: -370px;
		left: 50%;
	}
	#nonJsForm label {
		padding-top: 6px;
		padding-right: 5px;
		float: left;
		width: 100px;
		text-align: right;
	}
	.defbutton {
		font-weight: bold;
	}
	.zerosize {
		width: 0px;
		height: 0px;
		overflow: hidden;
	}
	#colorPickerDiv a, #colorPickerDiv a:hover {
		padding: 1px;
		text-decoration: none;
		border-bottom: 0px;
	}
</style>
<?php
}

function kubrick_theme_page() {
	if ( isset( $_REQUEST['saved'] ) ) echo '<div id="message" class="updated fade"><p><strong>'.__('Options saved.').'</strong></p></div>';
?>
<div class='wrap'>
	<h2><?php _e('Customize Header'); ?></h2>
	<div id="kubrick-header">
		<div id="headwrap">
			<div id="header">
				<div id="headerimg">
					<h1><?php bloginfo('name'); ?></h1>
					<div class="description"><?php bloginfo('description'); ?></div>
				</div>
			</div>
		</div>
		<br />
		<div id="nonJsForm">
			<form method="post" action="">
				<?php wp_nonce_field('kubrick-header'); ?>
				<div class="zerosize"><input type="submit" name="defaultsubmit" value="<?php esc_attr_e('Save'); ?>" /></div>
					<label for="njfontcolor"><?php _e('Font Color:'); ?></label><input type="text" name="njfontcolor" id="njfontcolor" value="<?php echo esc_attr(kubrick_header_color()); ?>" /> <?php printf(__('Any CSS color (%s or %s or %s)'), '<code>red</code>', '<code>#FF0000</code>', '<code>rgb(255, 0, 0)</code>'); ?><br />
					<label for="njuppercolor"><?php _e('Upper Color:'); ?></label><input type="text" name="njuppercolor" id="njuppercolor" value="#<?php echo esc_attr(kubrick_upper_color()); ?>" /> <?php printf(__('HEX only (%s or %s)'), '<code>#FF0000</code>', '<code>#F00</code>'); ?><br />
				<label for="njlowercolor"><?php _e('Lower Color:'); ?></label><input type="text" name="njlowercolor" id="njlowercolor" value="#<?php echo esc_attr(kubrick_lower_color()); ?>" /> <?php printf(__('HEX only (%s or %s)'), '<code>#FF0000</code>', '<code>#F00</code>'); ?><br />
				<input type="hidden" name="hi" id="hi" value="<?php echo esc_attr(kubrick_header_image()); ?>" />
				<input type="submit" name="toggledisplay" id="toggledisplay" value="<?php esc_attr_e('Toggle Text'); ?>" />
				<input type="submit" name="defaults" value="<?php esc_attr_e('Use Defaults'); ?>" />
				<input type="submit" class="defbutton" name="submitform" value="&nbsp;&nbsp;<?php esc_attr_e('Save'); ?>&nbsp;&nbsp;" />
				<input type="hidden" name="action" value="save" />
				<input type="hidden" name="njform" value="true" />
			</form>
		</div>
		<div id="jsForm">
			<form style="display:inline;" method="post" name="hicolor" id="hicolor" action="<?php echo esc_attr($_SERVER['REQUEST_URI']); ?>">
				<?php wp_nonce_field('kubrick-header'); ?>
	<input type="button"  class="button-secondary" onclick="tgt=document.getElementById('fontcolor');colorSelect(tgt,'pick1');return false;" name="pick1" id="pick1" value="<?php esc_attr_e('Font Color'); ?>"></input>
		<input type="button" class="button-secondary" onclick="tgt=document.getElementById('uppercolor');colorSelect(tgt,'pick2');return false;" name="pick2" id="pick2" value="<?php esc_attr_e('Upper Color'); ?>"></input>
		<input type="button" class="button-secondary" onclick="tgt=document.getElementById('lowercolor');colorSelect(tgt,'pick3');return false;" name="pick3" id="pick3" value="<?php esc_attr_e('Lower Color'); ?>"></input>
				<input type="button" class="button-secondary" name="revert" value="<?php esc_attr_e('Revert'); ?>" onclick="kRevert()" />
				<input type="button" class="button-secondary" value="<?php esc_attr_e('Advanced'); ?>" onclick="toggleAdvanced()" />
				<input type="hidden" name="action" value="save" />
				<input type="hidden" name="fontdisplay" id="fontdisplay" value="<?php echo esc_attr(kubrick_header_display()); ?>" />
				<input type="hidden" name="fontcolor" id="fontcolor" value="<?php echo esc_attr(kubrick_header_color()); ?>" />
				<input type="hidden" name="uppercolor" id="uppercolor" value="<?php echo esc_attr(kubrick_upper_color()); ?>" />
				<input type="hidden" name="lowercolor" id="lowercolor" value="<?php echo esc_attr(kubrick_lower_color()); ?>" />
				<input type="hidden" name="headerimage" id="headerimage" value="<?php echo esc_attr(kubrick_header_image()); ?>" />
				<p class="submit"><input type="submit" name="submitform" class="button-primary" value="<?php esc_attr_e('Update Header'); ?>" onclick="cp.hidePopup('prettyplease')" /></p>
			</form>
			<div id="colorPickerDiv" style="z-index: 100;background:#eee;border:1px solid #ccc;position:absolute;visibility:hidden;"> </div>
			<div id="advanced">
				<form id="jsAdvanced" style="display:none;" action="">
					<?php wp_nonce_field('kubrick-header'); ?>
					<label for="advfontcolor"><?php _e('Font Color (CSS):'); ?> </label><input type="text" id="advfontcolor" onchange="advUpdate(this.value, 'fontcolor')" value="<?php echo esc_attr(kubrick_header_color()); ?>" /><br />
					<label for="advuppercolor"><?php _e('Upper Color (HEX):');?> </label><input type="text" id="advuppercolor" onchange="advUpdate(this.value, 'uppercolor')" value="#<?php echo esc_attr(kubrick_upper_color()); ?>" /><br />
					<label for="advlowercolor"><?php _e('Lower Color (HEX):'); ?> </label><input type="text" id="advlowercolor" onchange="advUpdate(this.value, 'lowercolor')" value="#<?php echo esc_attr(kubrick_lower_color()); ?>" /><br />
					<input type="button" class="button-secondary" name="default" value="<?php esc_attr_e('Select Default Colors'); ?>" onclick="kDefaults()" /><br />
					<input type="button" class="button-secondary" onclick="toggleDisplay();return false;" name="pick" id="pick" value="<?php esc_attr_e('Toggle Text Display'); ?>"></input><br />
				</form>
			</div>
		</div>
	</div>
</div>
<?php } 


// ===========================================
// ==== from here starts Unique functions ====
// ===========================================

// Function name:
//  - get_allimages 
// Description:
//  - Used for geting all images of a post or page
// Parameters:
// 	- postID: id of the post or page 
//  - size: can be thumbnail, medium, large or orginal
//  - excludefirst: set it with the position of the image you want to exclude
// Returns:
//  - the HTML code with all images for a post or page

function get_allimages($postID, $size='thumbnail', $excludefirst=-1) {
	 
	    $iPostID = $postID;
	 		
	    $arrImages =& get_children('post_type=attachment&post_mime_type=image&post_parent=' . $iPostID.'&orderby=menu_order&order=ASC' );
	 
	    if($arrImages) {
	 
	        $arrKeys = array_keys($arrImages);
	 
        	$num = 0;
	        foreach($arrKeys as $arrImage) {
	        $iNum = $arrImage;
	        
	        if($excludefirst != $num) {
	        
	        $sThumbUrl = wp_get_attachment_image_src($iNum, $size);
	        $sThumbUrlB = wp_get_attachment_image_src($iNum, 'original');
	 
					$content .= '<div class=ArticleThumbnail>';
	        $content .= '<span class="Content" style="background: url('.$sThumbUrl[0].') no-repeat center center #FFFFFF;"><a title="$(\'#ProductMainImage a\').lightBox();" href="'.$sThumbUrlB[0].'"></a></span>';					
					$content .= '</div>';
					}
					$num++;
	 				}

        return $content;
	    }
	}
	
function get_allvideos($postID, $size='thumbnail', $excludefirst=-1) {
	 
	    $iPostID = $postID;
	 		
	    $arrImages =& get_children( 'post_type=attachment&post_mime_type=video/mp4' );

	 		print_r ($arrImages);
	 
	    if($arrImages) {
	 
	        $arrKeys = array_keys($arrImages);
	 
        	$num = 0;
	        foreach($arrKeys as $arrImage) {
	        $iNum = $arrImage;
	        
	        if($excludefirst != $num) {
	        
	        $sThumbUrl = wp_get_attachment_image_src($iNum, $size);
	        $sThumbUrlB = wp_get_attachment_image_src($iNum, 'original');
	 
					$content .= '<div class=ArticleThumbnail>';
	        $content .= '<span class="Content" style="background: url('.$sThumbUrl[0].') no-repeat center center #FFFFFF;"><a title="$(\'#ProductMainImage a\').lightBox();" href="'.$sThumbUrlB[0].'"></a></span>';					
					$content .= '</div>';
					}
					$num++;
	 				}

        return $content;
	    }
	}

// Function name:
//  - get_promo_images 
// Description:
//  - Used for geting the images for homepage promo
// Parameters:
// 	- postID: id of the post or page who apears on the promo
//  - PromoNr: the number of promo starting with 1 - is used to create ids of the objescts in order to be used in javascript functions
// Returns:
//  - the HTML code for creating promo images for a page or post

function get_two_thumbnails_promo($promos_link,$promos_picture1,$promos_picture2, $PromoNr) {
	

	 	
	 	//$arrKeys = array_keys($arrImages);
	 	//$sThumbUrl = wp_get_attachment_image_src($arrKeys[0], 'medium');
		$sImgString = '<div class="MediumThumbnail" id=MediumThumbnail'.$PromoNr.' style="display: none;">';								
		$sImgString .= '<span id="MTC'.$PromoNr.'" class="Content" style="display: none; background: url('. $promos_picture1 .') no-repeat center center #FFFFFF;"><a href="'.$promos_link.'"></a></span>';
		$sImgString .= '</div>';
		
		//$sThumbUrl = wp_get_attachment_image_src($arrKeys[1], 'large');
		//if (strlen($sThumbUrl[0]) == 0) {
		//	$sThumbUrl = wp_get_attachment_image_src($arrKeys[0], 'large');
		//}
		$sImgString .= '<div class="BigThumbnail" id=BigThumbnail'.$PromoNr.' style="display: none;">';								
		$sImgString .= '<span id="BTC'.$PromoNr.'" class="Content" style="display: none; background: url('. $promos_picture2 .') no-repeat center center #FFFFFF;"><a href="'.$promos_link.'"></a></span>';
		$sImgString .= '</div>';
	
		return $sImgString;

}

function get_one_thumbnail_promo($promos_link,$promos_picture1, $PromoNr) {
	

	 	
	 	//$arrKeys = array_keys($arrImages);
	 	//$sThumbUrl = wp_get_attachment_image_src($arrKeys[0], 'original');
		$sImgString = '<div class="LargeThumbnail" id=LargeThumbnail'.$PromoNr.' style="display: none;">';								
		$sImgString .= '<span id="LTC'.$PromoNr.'" class="Content" style="display: none; background: url('. $promos_picture1 .') no-repeat center center #FFFFFF;"><a href="'.$promos_link.'"></a></span>';
		$sImgString .= '</div>';
		
		return $sImgString;

}

function get_fullpicture_promo($promos_link,$promos_picture1, $PromoNr) {

	 	
	 	//$arrKeys = array_keys($arrImages);
	 	//$sThumbUrl = wp_get_attachment_image_src($arrKeys[0], 'original');
		$sImgString = '<div class="FullPicture" id=FullPicture'.$PromoNr.' style="display: none;">';								
		$sImgString .= '<span id="FPC'.$PromoNr.'" class="Content" style="display: none; background: url('. $promos_picture1 .') no-repeat center center transparent;"><a href="'.$promos_link.'"></a></span>';
		$sImgString .= '</div>';
		
		return $sImgString;

}

function get_fullpage_promo($promos_link,$promos_picture1, $PromoNr) {

	 	$logosize = getimagesize(get_absolute_url(get_bloginfo('stylesheet_directory').'/images/logos/'.get_headerinfo('logo', 1))); 
	 	$topdistance = $logosize[1]+53;
	 	$topdistance1 = $logosize[1]+63;
	 		 	
	 	//$arrKeys = array_keys($arrImages);
	 	//$sThumbUrl = wp_get_attachment_image_src($arrKeys[0], 'original');
		$sImgString = '<div class="FullPage" id=FullPage'.$PromoNr.' style="display: none; top: '.$topdistance.'px ;">';		
		$sImgString .= '<span id="FPAC'.$PromoNr.'" class="Content" style="display: none; background: url('. $promos_picture1 .') no-repeat center center transparent;"></span>';
		$sImgString .= '</div>';
		$sImgString .= '<a href="'.$promos_link.'" class="FullPageLink" style=" top: '.$topdistance1.'px ;"></a>';
		
		return $sImgString;
		
}

function get_promo_images($Pkey, $PromoNr) {
 
 //$iPostID = $postID;
	 		
 //$arrImages =& get_children('post_type=attachment&post_mime_type=image&post_parent=' . $iPostID.'&orderby=menu_order&order=ASC' );
 include(get_absolute_url(get_bloginfo('stylesheet_directory').'/promos.php'));
 include get_absolute_url((get_bloginfo('stylesheet_directory').'/promo_config.php'));

 
 
 switch($promo_type) {
  case 1: return get_two_thumbnails_promo($promos_link[$Pkey],$promos_picture1[$Pkey],$promos_picture2[$Pkey], $PromoNr); break;	
  case 2: return get_one_thumbnail_promo($promos_link[$Pkey],$promos_picture1[$Pkey], $PromoNr); break;	
  case 3: return get_fullpicture_promo($promos_link[$Pkey],$promos_picture1[$Pkey], $PromoNr); break;	
  case 4: return get_fullpage_promo($promos_link[$Pkey],$promos_picture1[$Pkey], $PromoNr); break;	
  //case 5: return get_quer_promo($promos_link[$PromoNr],$promos_picture1[$PromoNr],$promos_picture2[$PromoNr], $PromoNr, $PromoNr); break;	
 }

 
}

// Function name:
//  - get_one_image 
// Description:
//  - Used for geting an images - is used in listing pagetypes and for getting the big picture for pages and posts
// Parameters:
// 	- postID: id of the post or page - if you set it -1, or not set it will retreive an array with all images
//  - pos: the position of the image you want to retreive
//  - size: can be thumbnail, medium, large or orginal
// Returns:
//  - the url of an image

function get_one_image($postID, $pos=-1, $size='thumbnail') {
			$sImgString = array();
	    $iPostID = $postID;
	 		
	    $arrImages =& get_children('post_type=attachment&post_mime_type=image&post_parent='.$iPostID.'&orderby=menu_order&order=ASC');
	 
	 
	    if($arrImages) {
	 
	        $arrKeys = array_keys($arrImages);
	 
        	$i = 0;
	        foreach($arrKeys as $arrImage) {
	        $iNum = $arrImage;
	 
	        
	        $sThumbUrl = wp_get_attachment_image_src($iNum, $size);
	 
	 				$sImgString[$i] = $sThumbUrl[0];
					
	        $i++;         
	 				}

        if ($pos != -1) {
        	return $sImgString[$pos];

        }        
        
        else {
        	return $sImgString;
        }
        
	    }
	    //else {
	    //	$noimgpath = get_bloginfo('stylesheet_directory').'/images/nopicture.gif';
       // return $noimgpath;
	    //}	
}


// Function name:
//  - the_breadcrumbs 
// Description:
//  - Used for creating the breadcrumbs for all pages
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for breadcrumbs

function the_breadcrumbs() {
	$bc_data = array();
	
	
	
	$homelink = '<span class=BC>You are here</span><a class="BCLink firstdepth" href="'.get_bloginfo('wpurl').'/index.php"><span>Home</span></a>';
	
	if (is_category() == true){
		
		
		$cat_name = single_cat_title($prefix = '', $display = false );
		$cat_id = get_cat_ID($cat_name);
		
		//echo $cat_id;
		$cat = get_category($cat_id);
		$cat_parent_id = $cat->parent;
		
		
		$i = 0;						
		while ($cat_parent_id != 0) 	{
		
		$cat = get_category($cat_parent_id);
		$bc_data[$i] = '<a class="BCLink" href="'.get_category_link( $cat_parent_id ).'"><span>'.$cat->name.'</span></a>';					
		$cat_parent_id = $cat->parent;
		
		$i++;		
		}
		
		$breadcrumbs = '';
		for ($i =  count($bc_data)-1; $i >= 0 ; $i--) {
			$breadcrumbs .= $bc_data[$i];
		}		
		
		$breadcrumbs .= '<span class="BCActual">'.$cat_name.'</span>';
		echo $homelink.$breadcrumbs;
	}			
	
	if (is_page() == true){								
		$page_id = get_the_ID();
		
		$page = get_post($page_id);
		$parent_id = $page->post_parent;
		
		$i = 0;		
		
		while ($parent_id != 0) {
			
			$page_parent = get_page($parent_id);
			$bc_data[$i] = '<a class="BCLink" href="'.get_page_link( $parent_id ).'"><span>'.$page_parent->post_title.'</span></a>';
			$parent_id = $page_parent->post_parent;
			$i++;
			
		}
		
		$breadcrumbs = '';
		for ($i =  count($bc_data)-1; $i >= 0 ; $i--) {
			$breadcrumbs .= $bc_data[$i];
		}
		echo $homelink.$breadcrumbs;
		echo '<span class="BCActual">'.$page->post_title.'</span>';
	}
	
	if(is_single()) {
		$category = get_the_category();
		$cat_id = get_cat_ID($category[0]->cat_name);
		
								
		$cat = get_category($cat_id);
		$cat_parent_id = $cat->parent;								
								
		$i = 0;						
		while ($cat_parent_id != 0) 	{
		
		$cat = get_category($cat_parent_id);
		$bc_data[$i] = '<a class="BCLink" href="'.get_category_link( $cat_parent_id ).'"><span>'.$cat->name.'</span></a>';					
		$cat_parent_id = $cat->parent;
		
		$i++;		
		}
		
		$breadcrumbs = '';
	
		for ($i =  count($bc_data)-1; $i >= 0 ; $i--) {
			$breadcrumbs .= $bc_data[$i];
		}		

		$breadcrumbs .= '<a class="BCLink" href="'.get_category_link( $cat_id ).'"><span>'.$category[0]->cat_name.'</span></a>';					
								
		echo $homelink.$breadcrumbs;
		echo '<span class="BCActual">';
		the_title(); 
		echo '</span>';							
	}
	
	if( is_tag()) {
		echo $homelink;
		echo '<span class="BCActual">';
		echo 'Posts Tagged &#8216 '; 
		single_tag_title(); 
		echo ' &#8217';
		echo '</span>';
	} 
	if (is_day()) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Archive for ';
		the_time('F jS, Y'); 
		echo '</span>';		
	}
	if (is_month()) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Archive for ';
		the_time('F, Y');
		echo '</span>';		
	}
	if (is_year()) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Archive for ';
		the_time('Y');
		echo '</span>';		
	}
	if (is_author()) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Author Archive';
		echo '</span>';		
	}
	if (is_search()) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Search results';
		echo '</span>';		
	}	
	if (isset($_GET['paged']) && !empty($_GET['paged'])) { 
		echo $homelink;
		echo '<span class="BCActual">';		
		echo 'Blog Archives';
		echo '</span>';		
	} 
	
	
}

// Function name:
//  - portfolio_listing 
// Description:
//  - Used for creating the portfolio listing page
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for portfolio listing page content

function portfolio_listing() {
  global $posts_per_page;
	$cat_name = single_cat_title($prefix = '', $display = false );
	$cat_id = get_cat_ID($cat_name);
  
  $content = '<div class=StyleSelector>';
	$content .= '<span>Choose a list style</span>';
	$content .= '<a id="boxbig" class="boxbig C5bg" href="#" onclick="SwitchListType(\'boxbig\'); return false;"><span></span></a> ';
	$content .= '<a id="boxsmall" class="boxsmall C5bg" href="#" onclick="SwitchListType(\'boxsmall\'); return false;"><span></span></a> ';
	$content .= '<a id="listbig" class="listbig C5bg" href="#" onclick="SwitchListType(\'listbig\'); return false;"><span></span></a>';
	$content .= '<a id="listsmall" class="listsmall C5bg" href="#" onclick="SwitchListType(\'listsmall\'); return false;"><span></span></a>';
	$content .= '</div>';
	
	$content .= '<div id=PortfolioList class=PortfolioList>';
	$ordered_sections = get_ordered_sections($cat_id);
	$currentpage = get_current_page('currentpage');
	$first_post = ($currentpage-1)*$posts_per_page;
	$last_post = $currentpage*$posts_per_page;
	$i = 1;
	$postnr = 1;
  foreach ($ordered_sections as $page) {
  
	$section_id = intval(substr($page, 1));
	$section_type = substr($page, 0, 1);
	
	if ($section_type == 'p') { 
		if ($i > $first_post && $i <= $last_post) {
	
		$post_data = get_post($section_id);

			
	$content .= '<span class="PortfolioItem">';					
	$content .= '<div class=PortfolioThumbnail>';
	$content .= '<span id="PortfolioMediumTh" class="Content" style="background:url('.get_one_image($post_data->ID, 0, 'medium').') no-repeat center center;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
	$content .= '<span id="PortfolioSmallTh" class="Content" style="background:url('.get_one_image($post_data->ID, 0, 'thumbnail').') no-repeat center center;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
	$content .= '</div>';
	$content .= '<span id="ItemContent">';					
	$content .= '<h2><a href="'.get_permalink($post->ID).'">'.$post_data->post_title.'</a></h2>';
	$content .= '<span class=ItemInfos>';

	$exclude_custom_keys = array('article_type', 'homepage');
	
  $custom_field_keys = get_post_custom_keys($post_data->ID);
  foreach ( $custom_field_keys as $key => $value ) {
	
    $valuet = trim($value);
      if ( '_' == $valuet{0} )
      continue;
	 $keyvalue = $value;

   $exclude = 0;
	 foreach($exclude_custom_keys as $exclude_key) {
		if ($exclude_key == $value) {
			$exclude = 1;
		}
	 }	

	 if ($exclude != 1) {

   $mykey_values = get_post_custom_values($keyvalue);
   if (count($mkey_vales) > 1) {

   $content .= '<span class="'.str_replace(" ","",$value).'">'.$value.': ';
   

   $last_item = end($mykey_values);
		foreach ( $mykey_values as $key => $value ) {
    	$content .= $value;
    	if ($value != $last_item) {
    		$content .=', ';
    	}
  	}
  	
		
		$content .= '</span><br/>';
	}
		}
		
  }

	$content .= '</span>';
	$content .= '<p>';
	if (strlen($post_data->post_excerpt) > 0) {
	$content .= $post_data->post_excerpt;
	}
	else {
	$content .= substr ($post_data->post_content, 0, 270);
	}
	
	$content .= '</p>';
	$content .= '<a class="Button" href="'.get_permalink($post_data->ID).'"><span>details</span></a>';
	$content .= '</span>';
	$content .= '</span>';

	if (($postnr-1)%4 == 3 && $i!=1) {
	$content .= '<div class="element4"></div>';
	}
	if (($postnr-1)%3 == 2 && $i!=1) {
	$content .= '<div class="element3"></div>';
	}		
	
	$postnr++;
	
	}	
	
	
	
	
	$i++;
}
	}
	
	$content .= '</div>';	
	$content .= get_category_pages($i-1, $cat_id);

	return $content;
	
}

// add the shortcode for portfolio listing 

add_shortcode('portfolio', 'portfolio_listing');


// Function name:
//  - products_listing 
// Description:
//  - Used for creating the products listing page
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for products listing page content

function products_listing() {
  global $posts_per_page;
	$cat_name = single_cat_title($prefix = '', $display = false );
	$cat_id = get_cat_ID($cat_name);
	
	$content = '<div class=StyleSelector>';
	$content .= '<span>Choose a list style</span>';
	$content .= '<a id="boxbig" class="boxbig C5bg" href="#" onclick="SwitchListType(\'boxbig\'); return false;"><span></span></a> ';
	$content .= '<a id="boxsmall" class="boxsmall C5bg" href="#" onclick="SwitchListType(\'boxsmall\'); return false;"><span></span></a> ';
	$content .= '<a id="listbig" class="listbig C5bg" href="#" onclick="SwitchListType(\'listbig\'); return false;"><span></span></a>';
	$content .= '<a id="listsmall" class="listsmall C5bg" href="#" onclick="SwitchListType(\'listsmall\'); return false;"><span></span></a>';
	$content .= '</div>';
	
	$content .= '<div id=PortfolioList class=PortfolioList style="">';
	
	$currentpage = get_current_page('currentpage');
	$first_post = ($currentpage-1)*$posts_per_page;
	
	$last_post = $currentpage*$posts_per_page;
	$i = 1;
		
	$ordered_sections = get_ordered_sections($cat_id);
  $postnr = 1;
  foreach ($ordered_sections as $page) {
  	
	$section_id = intval(substr($page, 1));	
	$section_type = substr($page, 0, 1);
	
	if ($section_type == 'p') {
		if ($i > $first_post && $i <= $last_post) {	
	
	$post_data = get_post($section_id);
			
	$content .= '<span class="PortfolioItem">';					
	$content .= '<div class=PortfolioThumbnail>';
	$content .= '<span id="PortfolioMediumTh" class="Content" style="background:url('.get_one_image($post_data->ID, 0, 'medium').') no-repeat center center;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
	$content .= '<span id="PortfolioSmallTh" class="Content" style="background:url('.get_one_image($post_data->ID, 0, 'thumbnail').') no-repeat center center;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
	$content .= '</div>';
	$content .= '<span id=ItemContent>';
	$content .= '<h2><a href="'.get_permalink($post_data->ID).'">'.$post_data->post_title.'</a></h2>';	

	$oldprice_exist = 0;
	$price_exist = 0;
 	$custom_field_keys = get_post_custom_keys($post_data->ID);	
  foreach ( $custom_field_keys as $key => $value ) {
  	if ($value == 'old_price') {
  		$oldprice_exist = 1;
  	}
  	if ($value == 'price') {
  		$price_exist = 1;
  	}
  }
	if ($price_exist == 1) {
	$content .= '<span class=ItemInfos><span class="Prices"><span class="PricesBackground">';	
	}
	
 	asort($custom_field_keys);
  foreach ($custom_field_keys as $key => $value ) {
	
    $valuet = trim($value);
      if ( '_' == $valuet{0} )
      continue;
	 $keyvalue = $value;

	 if ($value == 'old_price' || $value == 'price') {

	 $class = $value;
	 if ($oldprice_exist == 1 && $value == 'price') {
	 	$class = $value.' oldpriceexist';	
	 }

   $content .= '<span class="'.$class.'"><span>';
   
   $mykey_values = get_post_custom_values($keyvalue, $post_data->ID);
   
	foreach ( $mykey_values as $key => $value ) {
   	$content .= $value;
  	}
		
		$content .= '</span></span>';
		}
		
  }
	if ($price_exist == 1) {
	$content .= '</span></span></span>';
	}
	$content .= '<p>';
	if (strlen($post_data->post_excerpt) > 0) {
	$content .= substr ($post_data->post_excerpt, 0, 270);
	}
	else {
	$content .= substr ($post_data->post_content, 0, 270);
	}
	
	$content .= '</p>';
$content .= '<a class="Button" href="'.get_permalink($post_data->ID).'"><span>details</span></a>';		
	$content .= '</span>';
	$content .= '</span>';
	

	if (($postnr-1)%4 == 3 && $i!=1) {
	
	$content .= '<div class="element4"></div>';
	}
	if (($postnr-1)%3 == 2 && $i!=1) {
	$content .= '<div class="element3"></div>';
	}		
	$postnr++;
	}
	$i++;

	}
	}

	$content .= '</div>';	
	$content .= '<div class="CleanerLeft"></div>';	
	$content .= get_category_pages($i-1, $cat_id);

	return $content;
	
}

// add the shortcode for products listing 

add_shortcode('products', 'products_listing');



// Function name:
//  - blog_listing 
// Description:
//  - Used for creating the blog listing page
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for blog listing page content

function blog_listing() {
	global $posts_per_page;
	$cat_name = single_cat_title($prefix = '', $display = false );
	$cat_id = get_cat_ID($cat_name);
	
	//$postslist = get_posts('category='.$cat_id.'&$numberposts=-1&order=ASC&orderby=category');

	
	$currentpage = get_current_page('currentpage');
	$first_post = ($currentpage-1)*$posts_per_page;
	
	$last_post = $currentpage*$posts_per_page;
	$i = 1;
		
	$ordered_sections = get_ordered_sections($cat_id);
  
  $content .= '<div id=ListingList class=ListingList>';
  
  foreach ($ordered_sections as $page) {
  	
	$section_id = intval(substr($page, 1));	
	$section_type = substr($page, 0, 1);
	
	if ($section_type == 'p') {
		if ($i > $first_post && $i <= $last_post) {	
			
	$post_data = get_post($section_id);
	$content .= '<div id=ListingItem class="ListingItem';
	if ($i == 1) {
	$content .= ' firstitem';
	}
	$content .= '">';
	$content .= '<h1><a href="'.get_permalink($post_data->ID).'">'.$post_data->post_title.'</a></h1>';
	$content .= '<span id="PostContent" class=PostInfos>';
	$content .= '<span class="PostDate">'.$post_data->post_date_gmt.'</span>';
	$content .= '<span class="PostComments"><a class="PostInfosLink" href="'.get_permalink($post_data->ID).'">'.$post_data->comment_count.' comments</a></span>';
	$content .= '<span class="Categories">';
	
	$categories = get_the_category($post_data->ID);
	$last_item = end($categories);
	foreach($categories as $category) {
	$content .= '<a class="PostInfosLink" href="'.get_category_link($category->cat_ID).'">'.$category->cat_name.'</a>';
	
	if ($last_item != $category) {
	$content .= ', ';
	}
	
	$content .= '</span>';
	
	
	$tagslist = get_the_tags($post_data->ID);
	if (count($taglist) > 0) {
	$content .= '<span class="Tags">';

	if (count($tagslist) > 1) {
	$last_item = end($tagslist);
	foreach($tagslist as $tags) {
	$content .= '<a class="PostInfosLink" href="'.get_tag_link($tags->term_id).'">'.$tags->name.'</a>';

	if ($last_item != $tags){
	$content .= ', ';
	}
		
	}
	}
	$content .= '</span>';
	}
	$content .= '</span>';
					
	$content .= '<p>';
	
	if (strlen($post_data->post_excerpt) > 0) {
	$content .= $post_data->post_excerpt;
	}
	else {
	$content .= substr ($post_data->post_content, 0, 600);
	}
	
	$content .= '</p>';
	$content .= '<a class="Button" href="'.get_permalink($post_data->ID).'"><span>read more</span></a>';
		
	}
	$content .= '</div>';
	
}
	$i++;
}
}

	$content .= '</div>';
	$content .= get_category_pages($i-1, $cat_id);

	return $content;
	
}


// add the shortcode for blog pages

add_shortcode('blog', 'blog_listing');



// Function name:
//  - get_category_pages 
// Description:
//  - Used for creating pages buttons on listing pages
// Parameters:
// 	- total_posts: number of total post of a category
//  - cat_id: the category id
// Returns:
//  - the HTML code for pages buttons 

function get_category_pages($total_posts, $cat_id) {
	global $posts_per_page;
	
	$nrpages = $total_posts/$posts_per_page;
	$pages = intval($nrpages);
	$currentpage = get_current_page('currentpage');
	
	
	if ($nrpages > $pages) {
		$pages_nr = $pages+1;
	}
	else {
		$pages_nr = $pages;
	}
	$content = '<div class="Pages CBR2">';
	$content .= '<span class=PageNumbers>';
	if ($pages_nr > 1) {
		for($i = 1 ; $i <= $pages_nr ; $i++) {
			$content .= '<a class="PageLink ';

				if ($currentpage == $i) {
					$content .= 'CurrentPage';
				}
				
				if ($i == 1) {
					$content .= 'depth1 ';
				}

				if ($i == $pages_nr) {
					$content .= 'depth3 ';
				}		
				
			if (get_option('permalink_structure') != '') {
				$content .= '" href="'.get_category_link($cat_id).'page/'.$i.'/"><span>'.$i.'</span></a>';
			}
			else {
				$content .= '" href="'.get_category_link($cat_id).'&pagenr='.$i.'"><span>'.$i.'</span></a>';
			}
		}
	}
	
	$content .= '</span>';
	$content .= '<span class=PageNumber>Page '.$currentpage.' of '.$pages_nr.'</span>';
	$content .= '</div>';
	
	if($pages_nr > 1) {
		return $content;
	}
	
}

// Function name:
//  - get_current_page 
// Description:
//  - Used for getting the curent page for categories with pages browsing
// Parameters:
// 	- opt: can be:
//           - currentpage - for returning the current page
//           - offset - for returning the last post of the previous page
// Returns:
//  - see parameters

function get_current_page($opt) {
	global $posts_per_page;
	
	if (get_option('permalink_structure') != '') {
	
			$current_page = array();
			$current_page = explode("/", $_SERVER['REQUEST_URI']);
			$el = count($current_page)-3;
			$check = $current_page[$el];
			
			if ($check == 'page') {
			$el = count($current_page)-2;
			$page_nr = $current_page[$el];
			$offset = ($current_page[$el]-1)*$posts_per_page;
				
				if ($offset < 0) {
					$offset = 0;
				}
			}
			else {
				
				$offset = 0;
				$page_nr = 1;
					
			}
	}
	else {
		$page_nr = $_GET['pagenr'];
		if ($page_nr) {
			$offset = ($page_nr-1)*$posts_per_page;
		}
		else {
			$offset = 0;
			$page_nr = 1;			
		}
	}
	
	if ($opt == 'offset') {
		return $offset;
	}
	if ($opt == 'currentpage') {
		return $page_nr;
	}	
	
}

// Function name:
//  - normal_listing 
// Description:
//  - Used for creating the code for a normal posts listing
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for normal post listing

function normal_listing() {
	global $posts_per_page;
	
	$cat_name = single_cat_title($prefix = '', $display = false );
	$cat_id = get_cat_ID($cat_name);
	
	//$postslist = get_posts('category='.$cat_id.'&order=ASC&orderby=category&numberposts=0&offset='.get_current_page('offset'));
	$nrposts = get_posts('category='.$cat_id.'&order=ASC&orderby=category&numberposts=-1');
	$total_posts = count($nrposts);
	
	$ordered_sections = get_ordered_sections($cat_id);
	$currentpage = get_current_page('currentpage');
	$first_post = ($currentpage-1)*$posts_per_page;
	$last_post = $currentpage*$posts_per_page;
	$i = 1;
	$content = '<div id=ListingList class=ListingList>';
	foreach ($ordered_sections as $page) {
  	
	$section_id = intval(substr($page, 1));	
	$section_type = substr($page, 0, 1);
	
	if ($section_type == 'p') {
		if ($i > $first_post && $i <= $last_post) {
		$post_data = get_post($section_id);
		
		$content .= '<div id=ListingItem class="ListingItem';
		if ($i == 1) {
		$content .= ' firstitem';
		}
		$content .= '">';
		if (strlen(get_one_image($post_data->ID, 0)) > 0) {
		$content .= '<div class=ListingThumbnail>';
		$content .= '<span class="Content" style="background: url('.get_one_image($post_data->ID, 0).') no-repeat center center;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
		$content .= '</div>';
		}
		$content .= '<h2><a href="'.get_permalink($post_data->ID).'">'.$post_data->post_title.'</a></h2>';
		$content .= '<p>';
		if (strlen($post_data->post_excerpt) > 0) {
		$content .= $post_data->post_excerpt;
		}
		else {
		$content .= substr ($post_data->post_content, 0, 350);
		}
		
		$content .= '</p>';
		$content .= '</div><div class="CleanerLeft"></div>';
	}
		$i++;
	}
	
	}
		$content .= '</div>';
		$content .= get_category_pages($i-1, $cat_id);

	return $content;
}

// Function name:
//  - archive_listing 
// Description:
//  - Used for creating the code for archive listings
// Parameters:
// 	archive_posts: ids list of archive posts
// Returns:
//  - the HTML code for archive listing

function archive_listing($archive_posts) {
	global $posts_per_page;
	
	$cat_name = single_cat_title($prefix = '', $display = false );
	$cat_id = get_cat_ID($cat_name);
	
	//$postslist = get_posts('category='.$cat_id.'&order=ASC&orderby=category&numberposts=0&offset='.get_current_page('offset'));
	//$nrposts = get_posts('category='.$cat_id.'&order=ASC&orderby=category&numberposts=-1');
	$total_posts = count($archive_posts);
	
	//$ordered_sections = get_ordered_sections($cat_id);
	$currentpage = get_current_page('currentpage');
	$first_post = ($currentpage-1)*$posts_per_page;
	$last_post = $currentpage*$posts_per_page;
	$i = 1;
	$content .= '<div id=ListingList class=ListingList>';
	foreach ($archive_posts as $page_id) {
  	
	$section_id = $page_id;	
	
		if ($i > $first_post && $i <= $last_post) {
		
		$post_data = get_post($section_id);
		
		$content .= '<div id=ListingItem class="ListingItem';
		if ($i == 1) {
		$content .= ' firstitem';
		}
		$content .= '">';
		if (strlen(get_one_image($post_data->ID, 0)) > 0) {
		$content .= '<div class=ListingThumbnail>';
		$content .= '<span class="Content" style="background: url('.get_one_image($post_data->ID, 0).') no-repeat center center #FFFFFF;"><a href="'.get_permalink($post_data->ID).'"></a></span>';
		$content .= '</div>';
		}
		$content .= '<h2><a href="'.get_permalink($post_data->ID).'">'.$post_data->post_title.'</a></h2>';
		$content .= '<p>';
		if (strlen($post_data->post_excerpt) > 0) {
		$content .= $post_data->post_excerpt;
		}
		else {
		$content .= substr ($post_data->post_content, 0, 270);
		}
		
		$content .= '</p>';
		$content .= '</div><div class="CleanerLeft"></div>';
	
		$i++;
	}
	
	}
		$content .= '</div>';
		$content .= get_category_pages($i-1, $cat_id);

	return $content;
	?>
		<?php while (have_posts()) : the_post(); ?>
		<div <?php post_class() ?>>
				<h3 id="post-<?php the_ID(); ?>"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h3>
				<small><?php the_time('l, F jS, Y') ?></small>

				<div class="entry">
					<?php the_content() ?>
				</div>

				<p class="postmetadata"><?php the_tags('Tags: ', ', ', '<br />'); ?> Posted in <?php the_category(', ') ?> | <?php edit_post_link('Edit', '', ' | '); ?>  <?php comments_popup_link('No Comments &#187;', '1 Comment &#187;', '% Comments &#187;'); ?></p>

			</div>

		<?php endwhile; ?>
	<?php
	
}


// Function name:
//  - blog_post 
// Description:
//  - Used for creating the code for a blog post
// Parameters:
// 	- no parameter
// Returns:
//  - the HTML code for blog post

function blog_post() {
	$post_id = get_the_ID();
	$post_data = get_post($post_id);
	
	$content .= '<h1>'.the_title('','', FALSE).'</h1>';
	
	$content .= '<span class=PostInfos>';
	$content .= '<span class="PostDate">'.$post_data->post_date.'</span>';
	$content .= '<span class="PostComments"><a class="PostInfosLink" href="#comments">Goto comments</a></span>';
	$content .= '<span class="PostComments"><a class="PostInfosLink" href="#leavecomment">Leave a comment</a></span>';
	$content .= '</span>';
	
	$content .= '<p>'.get_the_excerpt().'</p>';
	$content .= '<p>'.apply_filters('the_content', get_the_content()).'</p>';
	
	$content .= '<span class=PostInfos>';
	$content .= '<span class="Categories">';
	
	$categories = get_the_category($post_id);
	$last_item = end($categories);
	foreach($categories as $category) {
	$content .= '<a class="PostInfosLink" href="'.get_category_link($category->cat_ID).'">'.$category->cat_name.'</a>';
	
	if ($last_item != $category)
	$content .= ', ';
	}
	
	$content .= '</span>';
	
	$tagslist = get_the_tags($post_id);
	if (count($taglist) > 0) {
	$content .= '<span class="Tags">';
	if (count($taglist) > 0) {
	$last_item = end($tagslist);
	foreach($tagslist as $tags) {
	$content .= '<a class="PostInfosLink" href="'.get_tag_link($tags->term_id).'">'.$tags->name.'</a>';

	if ($last_item != $tags){
	$content .= ', ';
	}
		
	}
}
	$content .= '</span>';	
}
	$content .= '</span>';

	
	return $content;
	
}

// add the shortcode for blog posts

add_shortcode('blog_post', 'blog_post');



// Function name:
//  - get_contact_link 
// Description:
//  - Used for getting the url for contact page
// Parameters:
// 	- ret: can be:
// 					- link: for retreiving the url for contact page
// 					- id: for retreiving the id for contact page
// Returns:
//  - see parameters

function get_contact_link($ret='link') {
	$contact = get_pages('hierarchical=0&meta_key=article_type&meta_value=contact');
	if ($ret == 'link') {
		return get_page_link($contact[0]->post_id);
	}	
	if ($ret == 'id') {
		return $contact[0]->post_id;
	}		
}

// Function name:
//  - portfolio_post 
// Description:
//  - Used for creating the portfolio detail page
// Parameters:
// 	- no parameters
// Returns:
//  - the HTML code for portfolio detail page

function portfolio_post() {

	$post_id = get_the_ID();
	$post_data = get_post($post_id);

	//echo get_allvideos($post_id);

	$content .= '<h1>'.the_title('','', FALSE).'</h1>';
	if ($post_data->post_excerpt) {
	$content .= '<span id=Description><span>';
	$content .= get_the_excerpt();		
	$content .= '</span></span>';	
	}
	$bigImages = get_one_image($post_data->ID, 0, 'original');
	$allImages = get_allimages($post_data->ID, 'thumbnail', 0);
	if ($bigImages) {
	$content .= '<div id="ProductMainImage" class=PhotoGallery>';
	$content .= '<div class=PortfolioMainThumbnail>';
	$content .= '<div class=PortfolioMainThumbnailContainer>';
	$content .= '<span class="Content" style="background: url('.get_one_image($post_data->ID, 0, 'large').') no-repeat center top;"><a title="$(\'#ProductMainImage a\').lightBox();" href="'.$bigImages.'"></a></span>';
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '<div class="ArticleImages" id="ArticleImages">';
	$content .= '<div class="ArticleImagesContainer">';
	if ($allImages) {				
	$content .= '<div class="GalleryTitle">Browse image gallery</div>';
	$content .= $allImages;
	}
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '</div>';				
	}
	$content .= '<p>';

  
	$exclude_custom_keys = array('article_type', 'homepage');
	
  $custom_field_keys = get_post_custom_keys($post_data->ID);
  if ( count($custom_field_keys) > 0) {
	$content .= '<span class="ItemInfos">';  	
  foreach ( $custom_field_keys as $key => $value ) {
	
    $valuet = trim($value);
      if ( '_' == $valuet{0} )
      continue;
	 $keyvalue = $value;

   $exclude = 0;
	 foreach($exclude_custom_keys as $exclude_key) {
		if ($exclude_key == $value) {
			$exclude = 1;
		}
	 }	

	 if ($exclude != 1) {

   $content .= '<span class="'.str_replace(" ","",$value).'">'.$value.': ';
   
   $mykey_values = get_post_custom_values($keyvalue, $post_data->ID);
   $last_item = end($mykey_values);
		foreach ( $mykey_values as $key => $value ) {
    	$content .= $value;
    	if ($value != $last_item) {
    		$content .=', ';
    	}
  	}
		
		$content .= '</span><br/>';
		}
		
  }
	$content .= '</span>';
	}	

	$content .= '<span class=PortfolioDetail>';
	$content .= '<a class="Button" href="'.get_contact_link().'"><span>request a quote</span></a>';	
	$content .= '</span>';
	$content .= '</p><p>';
	$content .= apply_filters('the_content', get_the_content());
	$content .= '</p>';
	$content .= '<div class="CleanerLeft"></div>';
	
	return $content;
}

// add the shortcode for portfolio post
add_shortcode('portfolio_post', 'portfolio_post');


// Function name:
//  - products_post 
// Description:
//  - Used for creating the products detail page
// Parameters:
// 	- no parameters
// Returns:
//  - the HTML code for products detail page

function products_post() {


	$post_id = get_the_ID();
	$post_data = get_post($post_id);
	
	$content .= '<h1>'.the_title('','', FALSE).'</h1>';
	if ($post_data->post_excerpt) {
	$content .= '<span id=Description><span>';
	$content .= get_the_excerpt();		
	$content .= '</span></span>';
	}
	$bigImages = get_one_image($post_data->ID, 0, 'original');
	$allImages = get_allimages($post_data->ID, 'thumbnail', 0);
	if ($bigImages) {
	$content .= '<div id="ProductMainImage" class=PhotoGallery>';
	$content .= '<div class=PortfolioMainThumbnail>';
	$content .= '<div class=PortfolioMainThumbnailContainer>';
	$content .= '<span class="Content" style="background: url('.get_one_image($post_data->ID, 0, 'large').') no-repeat center top;"><a title="$(\'#ProductMainImage a\').lightBox();" href="'.$bigImages.'"></a></span>';
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '<div class="ArticleImages" id="ArticleImages">';
	$content .= '<div class="ArticleImagesContainer">';
	if ($allImages) {				
	$content .= '<div class="GalleryTitle">Browse image gallery</div>';
	$content .= $allImages;
	}
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '</div>';				
	}
	$content .= '<p>';

  
	$exclude_custom_keys = array('article_type', 'homepage', 'old_price', 'price');
	
  $custom_field_keys = get_post_custom_keys($post_data->ID);
  if ( count($custom_field_keys) > 0) {
	$content .= '<span class=ItemInfos>';
	if (count(get_post_custom_values('price', $post_data->ID)) > 0) {
	$content .= '<span class=Prices><span class=PricesBackground>';  
	}	
  foreach ( $custom_field_keys as $key => $value ) {
	
	 	$keyvalue = $value;

   	 if ($value == 'old_price' || $value == 'price') {
		
	 
	 $class = $value;
	 if ($oldprice_exist == 1 && $value == 'price') {
	 	$class = $value.' oldpriceexist';	
	 }

   $content .= '<span class="'.$class.'"><span>';
   
   $mykey_values = get_post_custom_values($keyvalue, $post_data->ID);
   
	foreach ( $mykey_values as $key => $value ) {
   	$content .= $value;
  	}
		
		$content .= '</span></span>';
	
		}
		
  }	
  	if (count(get_post_custom_values('price', $post_data->ID)) > 0) {
		$content .= '</span>';
		$content .= '</span>';		
		}

}

	$content .= '<a class="Button" href="'.get_contact_link().'"><span>request a quote</span></a>';				
	$content .= '</span>';
	$content .= '</p><p>';

	$content .= apply_filters('the_content', $post_data->post_content);
	 $content .= '<table border=0 cellspacing=0 cellpadding=0 class=TehnicalData>';
	 $content .= '<tbody>';	
  foreach ( $custom_field_keys as $key => $value ) {
	
    $valuet = trim($value);
      if ( '_' == $valuet{0} )
      continue;
	 $keyvalue = $value;

   $exclude = 0;
	 foreach($exclude_custom_keys as $exclude_key) {
		if ($exclude_key == $value) {
			$exclude = 1;
		}
	 }	
	
	 if ($exclude != 1) {

	 $content .= '<tr>';
	 $content .= '<td class="key">';
   $content .= $value;
   $content .= '</td>';
   $content .= '<td class="value">';
   $mykey_values = get_post_custom_values($keyvalue, $post_data->ID);
   //$last_item = end($mykey_values);
		foreach ( $mykey_values as $key => $value ) {
    	$content .= $value;
    	if ($value != $last_item) {
    		$content .=', ';
    	}
  	}
		
		$content .= '</td>';
		$content .= '</tr>';

		}
		
  }		
	$content .= '</tbody>';		
	$content .= '</table>';		
	$content .= '</p>';
	$content .= '<div class="CleanerLeft"></div>';	
	
	
	return $content;
}
// add the shortcode for products post
add_shortcode('products_post', 'products_post');


// Function name:
//  - normal_post 
// Description:
//  - Used for creating a normal article detail page
// Parameters:
// 	- no parameters
// Returns:
//  - the HTML code for normal posts detail page

function normal_post() {

	$post_id = get_the_ID();
	$post_data = get_post($post_id);
	
	$content .= '<h1>'.the_title('','', FALSE).'</h1>';
	if ($post_data->post_excerpt) {
	$content .= '<span id=Description><span>';
	$content .= get_the_excerpt();		
	$content .= '</span></span>';	
	}
	$bigImages = get_one_image($post_data->ID, 0, 'original');
	$allImages = get_allimages($post_data->ID, 'thumbnail', 0);
	if ($bigImages) {
	$content .= '<div id="ProductMainImage" class=PhotoGallery>';
	$content .= '<div class=PortfolioMainThumbnail>';
	$content .= '<div class=PortfolioMainThumbnailContainer>';
	$content .= '<span class="Content" style="background: url('.get_one_image($post_data->ID, 0, 'large').') no-repeat center top;"><a title="$(\'#ProductMainImage a\').lightBox();" href="'.$bigImages.'"></a></span>';
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '<div class="ArticleImages" id="ArticleImages">';
	$content .= '<div class="ArticleImagesContainer">';
	if ($allImages) {				
	$content .= '<div class="GalleryTitle">Browse image gallery</div>';
	$content .= $allImages;
	}
	$content .= '</div>';				
	$content .= '</div>';				
	$content .= '</div>';				
	}	
	$content .= apply_filters('the_content', $post_data->post_content);
	$content .= '<div class="CleanerLeft"></div>';
	
	echo $content;
}

// Function name:
//  - get_shortcode 
// Description:
//  - Used for getting a shortcode name from a string
// Parameters:
// 	- content: string for parsing
// Returns:
//  - the shortcode name without brackets

function get_shortcode($content) {
	
	$content = strstr($content, '[');
	$content = str_replace('[', '',$content);
	$content = explode(']', $content);
	$content = $content[0];
	//$content1 = strstr($content, ' ', 'true');
	
	if (strlen($content1) > 0) {
		return $content1;
	}
	else {
		return $content;
	}
	
}



function find_nextpos($ordered_sections, $startpos) {
	
	$max_pos = $startpos;
	while (array_key_exists($max_pos, $ordered_sections)) {
		$max_pos = $max_pos+1;
	}
	
	return $max_pos;
	
}

// Function name:
//  - get_ordered_sections 
// Description:
//  - Used for getting all sections, pages, posts or categories ordered. This function uses sections.xml file - generated from the admin section
// Parameters:
// 	- parent: the parent of the posts, pages and categories 
//  - exclude_posts: the ids of the posts witch must be excluded from the list
// Returns:
//  - array with all sections ordered

function get_ordered_sections($parent, $exclude_posts=0) {
	$ordered_sections  = array();
	
	// select exclude ids depending on what article_type customfiels its have
	
	$exclude = get_pages('hierarchical=0&meta_key=article_type&meta_value=footertext');
	foreach($exclude as $post) {
		$exclude_ids .= $post->ID.',';
	}
	
	$exclude = get_pages('hierarchical=0&meta_key=article_type&meta_value=footerlinks');
	$i=1;
	foreach($exclude as $post) {
		if ($i < count($exclude)) {
		$exclude_ids .= $post->ID.',';
		}
		else {
		$exclude_ids .= $post->ID;
		}
		
		$i++;
	}	
		
	// get all pages and categories for a parent
	$pages = get_pages('hierarchical=0&parent='.$parent.'&exclude='.$exclude_ids);
  $categories = get_categories('parent='.$parent);
  $posts = get_posts('category='.$parent.'&numberposts=-1');

	// order the list as you setted up in the admin panel

	// -- get the xml info 
	
	$xml_url = get_bloginfo('stylesheet_directory').'/sections.xml';
	$abs_xml_url = get_absolute_url($xml_url);
	$vars = xml2array($abs_xml_url, 0, 'tag');	
	$xml_sections = $vars['sections'];	
	
	// -- create an ordered array with level 0 sections (pages and categeories as well)
	
	foreach ($pages as $page) {		
		$pos = $xml_sections['a'.$page->ID];
		if (!$pos) {
			$pos = find_nextpos($ordered_sections, 9999);
		}			
		$ordered_sections[$pos] = 'a'.$page->ID;	
	}

	foreach ($categories as $category) {		
		$pos = $xml_sections['c'.$category->term_id];
		if (!$pos) {
			$pos = find_nextpos($ordered_sections, 9999);
		}			
		$ordered_sections[$pos] = 'c'.$category->term_id;	
	}	  
  
  if ($exclude_posts == 0) {
  
	foreach ($posts as $post) {		
		$cat = get_the_category($post->ID);

  	if ($cat[0]->term_id == $parent) {
			$pos = $xml_sections['p'.$post->ID];
		if (!$pos) {
			$pos = find_nextpos($ordered_sections, 9999);
		}			
			$ordered_sections[$pos] = 'p'.$post->ID;	
		}
	}	    
	}
  
  //print_r($ordered_sections);
  
  ksort($ordered_sections);
  
  return $ordered_sections;
}

// Function name:
//  - get_main_menu 
// Description:
//  - Used for creating the main menu and the drop down menus
// Parameters:
// 	- echo_data: can be:
//					- menu: for creating the main menu
// 					- dropdown: for creating the dropdown menus
// Returns:
//  - see parameters


function get_main_menu($echo_data) {

	include ('mainmenu_config.php');
	include ('mainmenu_exclude.php');
	include ('mainmenu_customlinks.php');
	
	$ordered_sections = get_ordered_sections(0);
  $content .= '<li id=MI1 class="first"><a id="MI1_link" class="selected" href="'.get_bloginfo('wpurl').'/index.php">'.$homepage_name.'</a></li>';
  $i = 2;
  $lastcount = 0;
  foreach ($ordered_sections as $page) {
  	$excludecat = 0;
	 	$section_type = substr($page, 0, 1);
	 	$section_id = intval(substr($page, 1));
	
	 	if ($section_type == 'a') { 
	 		$_page = get_page($section_id);
	 		$section_title = $_page->post_title;
	 		$section_link = get_page_link($section_id);
	 		$has_children = count(get_pages('parent='.$section_id.'&hierarchical=0'));
	 		$children = get_pages('parent='.$section_id.'&hierarchical=0');
	 		
	 		foreach($exclude_page_ids as $excludeid) {
	 			if ($section_id == $excludeid) {
	 				$excludecat = 1;
	 				$lastcount++;
	 			}
	 		}
	 		
	 	}
		
		if ($section_type == 'c') { 
			$_category = get_category($section_id);
	 		$section_title = $_category->cat_name;
	 		
	 		$section_link = get_category_link($section_id);		
	 		$has_children = count(get_categories('parent='.$section_id));
	 		$children = get_categories('parent='.$section_id);
	 		
	 		$reqshortcodename = get_shortcodename($section_id);
			
			if (!$reqshortcodename && $RemoveNormalCategories == 1) {
	 			$excludecat = 1;
	 			$lastcount++;
	 		}
			if ($reqshortcodename == 'blog' && $RemoveBlogCategories == 1) {
	 			$excludecat = 1;
	 			$lastcount++;
	 		}
			if ($reqshortcodename == 'portfolio' && $RemovePortfolioCategories == 1) {
	 			$excludecat = 1;
	 			$lastcount++;
	 		}
			if ($reqshortcodename == 'products' && $RemoveProductsCategories == 1) {
	 			$excludecat = 1;
	 			$lastcount++;
	 		}	 			 
	 		
	 		if ($excludecat != 1) {		
	 		
	 		foreach($exclude_category_ids as $excludeid) {
	 			if ($section_id == $excludeid) {
	 				$excludecat = 1;
	 				$lastcount++;
	 			}
	 		}	 			 		
	 		
	 		}
	 		
		}
		

		if ($excludecat != 1) {
   	
  	$content .= '<li id=MI'.$i;

  	if (count($ordered_sections)-$lastcount == $i-1) {
  		$content .= ' class="last"';
  	}
  	
  	$content .= '><a id="MI'.$i.'_link" ';

	  if ($has_children > 0) {
		  $content .= 'onmouseover="ShowDropDown(\'DD'.$i.'\', \'MI'.$i.'\');" ';
		  $content .= 'onmouseout="HideDropDown(\'DD'.$i.'\', \'MI'.$i.'\');" ';
	  }

	  $content .= 'href="'.$section_link.'">'.$section_title.'</a></li>';
    					
  	if ($has_children > 0) {
		
			$dd_content .= '<div id="DD'.$i.'" class="DropDown" >';
			$dd_content .= '<span class=DDTitle onmouseover="ShowDropDown(\'DD'.$i.'\', \'MI'.$i.'\');" onmouseout="HideDropDown(\'DD'.$i.'\', \'MI'.$i.'\');"><span class="DDTitleContent" id="DD'.$i.'_name"></span></span>';
			$dd_content .= '<span class=DDContent onmouseover="ShowDropDown(\'DD'.$i.'\', \'MI'.$i.'\');" onmouseout="HideDropDown(\'DD'.$i.'\', \'MI'.$i.'\');">';
			$dd_content .= '<ul>';
			$dd_content .= '<li>';
			$dd_content .= '<ul>';
		
			$ordered_children = get_ordered_sections($section_id, 1);
		
			$l = 1;
		
			foreach($ordered_children as $child) {
				
		 	$section_type = substr($child, 0, 1);
		 	$section_id = intval(substr($child, 1));
		
		 	if ($section_type == 'a') { 
		 		$_page = get_page($section_id);
		 		$section_title = $_page->post_title;
		 		$section_link = get_page_link($section_id);
		 	}
			
			if ($section_type == 'c') { 
				$_category = get_category($section_id);
		 		$section_title = $_category->cat_name;
		 		$section_link = get_category_link($section_id);		
			}
			
			if ($section_type == 'p') { 
				$_posts = get_post($section_id);
		 		$section_title = $_posts->post_title;
		 		$section_link = get_page_link($section_id);		
			}			
						
				$dd_content .= '<li><a class="DDLink" href="'.$section_link.'">'.$section_title.'</a></li>';

				if ((($l-1)%$DropDownItems == $DropDownItems-1) && $DropDownItems !=-1 ) $dd_content .= '</ul><ul>';
				
				$l++;
				
			}
								
			$dd_content .= '</ul>';
			$dd_content .= '</li>';
			$dd_content .= '</ul>';
			$dd_content .= '<div class="CleanerLeft"></div></span>';
			$dd_content .= '</div>';    						
    						
  	}
    					
  $i++;
  
}
	
  
  }
  
  if (count($links_name) > 0) {
  	
  	foreach($links_name as $key=>$value) {
  		
  		$content .= '<li><a href="'.$links_link[$key].'" target="'.$links_target[$key].'">'.$value.'</a></li>';
  		  		
  	}
  	
  }
     				
	if($echo_data == 'menu') {
		echo $content;
  }
  if($echo_data == 'dropdown') {
  	return $dd_content;
  }
    			
}


// Function name:
//  - get_contact_form 
// Description:
//  - Used for creating the contact form and sending emails to administrator email address
// Parameters:
// 	- act: url of contact page - is used to set the form action
// Returns:
//  - echo the contact form HTML

function get_contact_form($act) {
	$content .= '<div class="CommentsContainer">';
	if ($_POST['Email'] && $_POST['Comments']) {

		$to = get_bloginfo('admin_email');
		$subject = 'New message from your clients';
		$message = '
You have received a message from: 

Name: '.$_POST['FirstName'].' '.$_POST['LastName'].' 
Email: '.$_POST['Email'].' 
Address: '.$_POST['Address'].' 
City: '.$_POST['City'].' 
Zip: '.$_POST['Zip'].' 

And the message is: 
'.$_POST['Comments'];
		
		wp_mail($to, $subject, $message, $headers, $attachments);

		$content .= '<p>The message has been sent successfully. Thank you for your interest.</p>';

	}
	else {
		if ($_POST['sent'] == 1) {
			$content .= '<p>The message has not been sent. You must enter at least your email and a message.</p>';
		}
	}
	
	$content .= '
	<h2>Please send us a message using this form</h2>
	<div class="ContactForm">
	<form name="contactForm" method=POST action="'.$act.'">
	<input type=hidden name=sent value=1>
	<div class="CleanerLeft"></div>
	<input type=text name="FirstName"><label>First Name</label>
	<input type=text name="LastName"><label>Last Name</label>
	<input type=text name="Email"><label>Email</label>
	<input type=text name="Address"><label>Address</label>
	<input type=text name="City"><label>City</label>
	<input type=text name="Zip"><label>Zip</label>
	<textarea name="Comments"></textarea>
	<div class=Cleaner></div>
	<span class=Button onmouseover="this.className=\'Button_on\';" onmouseout="this.className=\'Button\';"><input name="submit" type="submit" id="submit" tabindex="5" value="Submit request" /></span>
	</form>
	</div>
	</div>';
	
	echo $content;
	
}


// Function name:
//  - get_browser 
// Description:
//  - retreive the browser name
// Parameters:
// 	- no parameter
// Returns:
//  - the browser name: Chrome, Safari, Gecko, Netscape, Firefox, MSIE 6, MSIE 7, MSIE 8, Opera

function get_php_browser() {

if ( strpos($_SERVER['HTTP_USER_AGENT'], 'Chrome') )
{
   $browser = 'chrome';
}
elseif ( strpos($_SERVER['HTTP_USER_AGENT'], 'Safari') )
{
   $browser = 'safari';
}
else if ( strpos($_SERVER['HTTP_USER_AGENT'], 'Gecko') )
{
   if ( strpos($_SERVER['HTTP_USER_AGENT'], 'Netscape') )
   {
     $browser = 'netscape';
   }
   else if ( strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox') )
   {
   	if (strpos($_SERVER['HTTP_USER_AGENT'], 'Firefox/2.0.0.20')) {
     $browser = 'firefox2';
   	}
   	else {
   		$browser = 'firefox3';
   	}
   }
   else
   {
     $browser = 'mozilla';
   }
}
else if ( strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') )
{
	if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE 6')){
		$browser = 'ie6';
	}
	elseif(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE 7')){
		$browser = 'ie7';
	}
	elseif(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE 8')){
		$browser = 'ie8';
	}
	else{
		$browser = 'ie';
	}
}
else if ( strpos($_SERVER['HTTP_USER_AGENT'], 'Opera') !== false)
{
   $browser = 'opera';
}
else
{
   $browser = 'other';
}

	return $browser;

}


// Function name:
//  - get_shortcodename
// Description:
//  - retreive the shorcode name of a category, or a parent category if is loaded a post page
// Parameters:
// 	- no parameter
// Returns:
//  - the shorcode name

function get_shortcodename($reqcategoryid='') {
			
		if (!$reqcategoryid) {

		if (is_post) {
			$category = get_the_category();
			$cat_id = get_cat_ID($category[0]->cat_name);
								
			while ($category[0]->category_parent != 0) 	{
				$cat_id = $category[0]->category_parent;
				$category = get_the_category($cat_id);
			}
								
			$category = get_category($cat_id);
			$shortcode = get_shortcode($category->description);			
		}
		else {
		
			$cat_name = single_cat_title($prefix = '', $display = false );
			$cat_id = get_cat_ID($cat_name);
			$category = get_category($cat_id);    	
	    $shortcode = get_shortcode($category->description);
  	}
  	}
  	else {
			$cat_id = $reqcategoryid;
			$category = get_category($cat_id);    	
	    $shortcode = get_shortcode($category->description);  		
  	}
  	
  	return $shortcode;
}

// Function name:
//  - get_headerinfo
// Description:
//  - retreive all information for website header 
// Parameters:
// 	- $ret - can be logo, header_tag, facebook_link, facebook_name, twitter_link, twitter_name
// Returns:
//  - see parameters

function get_headerinfo($ret, $echo=0) {
	
	$xml_url = get_bloginfo('stylesheet_directory').'/header.xml';
	$abs_xml_url = get_absolute_url($xml_url);
	$vars = xml2array($abs_xml_url, 0, 'tag');		
	$header = $vars['header'];
	if ($header[$ret]) {
		if ($echo != 1) {
			echo $header[$ret];
		}
		else {
			return $header[$ret];
		}
	}
	
}


// Function name:
//  - get_promo_thumbnails
// Description:
//  - prints the promo thumbnails
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for promo thumbnails

function get_promo_thumbnails() {
	  

    //$promoposts = get_pages('hierarchical=0&meta_key=article_type&meta_value=promo');
		include(get_absolute_url(get_bloginfo('stylesheet_directory').'/promos.php'));
		
		asort($promos_order); 
		$i = 1;
		foreach($promos_order as $key=>$value) {
    $promo_content.= get_promo_images($key, $i);
    $i++;
    }
    				
    //$promoposts = get_posts('meta_key=article_type&meta_value=promo');
					
		//foreach($promoposts as $post) {
    //$promo_content.= get_promo_images($post->ID, $i);
    //$i++;
    //}   
    echo $promo_content; 				
    
}

// Function name:
//  - get_promo_articles
// Description:
//  - prints the promo information
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for promo text and title

function get_promo_articles() {
	
	include(get_absolute_url(get_bloginfo('stylesheet_directory').'/promos.php'));
	//$promo_buttons = array();	
	asort($promos_order); 
	
	$i = 1;
	foreach($promos_order as $key=>$value) {
	
	$content .= '<div class=PromoInfo id="PromoInfo'.$i.'"';
	if ($i !=1) {
	$content .= ' style="display: none;"';
	}
	
	$content .= '>';
	$content .= '<div class="PromoText" id=PromoTitle'.$i.'>';
	$content .= '<h1><a href="'.$promos_link[$key].'" id="PT'.$i.'">'.$promos_title[$key].'</a></h1>';

	//$promocontent = substr($post->post_content, 0, 200);

	$content .= '<h2><span id="PC'.$i.'">'.$promos_text[$key].'</span></h2>';
	$content .= '</div>';
	$content .= '</div>';
						
	//$promo_titles[$i] = $post->post_title;	
	
	$i++;	
	}
	/*
	$promoposts = get_pages('hierarchical=0&meta_key=article_type&meta_value=promo');
	$i = 1;
					
	foreach($promoposts as $post) {
						
	$content .= '<div class=PromoInfo id="PromoInfo'.$i.'"';
						
	if ($i !=1) {
	$content .= ' style="display: none;"';
	}
						
						$content .= '>';
						$content .= '<div class="PromoText" id=PromoTitle'.$i.'>';
						$content .= '<h1><a href="'.get_permalink($post->ID).'" id="PT'.$i.'">'.$post->post_title.'</a></h1>';

						$promocontent = substr($post->post_content, 0, 200);

						$content .= '<h2><span id="PC'.$i.'">'.$promocontent.'</span></h2>';
						$content .= '</div>';
						$content .= '</div>';
						
						$promo_titles[$i] = $post->post_title;
						$i++;

					}

				

 					$promoposts = get_posts('meta_key=article_type&meta_value=promo');
					foreach($promoposts as $post) {

						$content .= '<div class=PromoInfo id="PromoInfo'.$i.'"';
						
						if ($i !=1) {
							$content .= ' style="display: none;"';
						}						
						
						$content .= '>';

						
						$content .= '<div class="PromoText" id=PromoTitle'.$i.'>';
						$content .= '<h1><a href="'.get_permalink($post->ID).'" id="PT'.$i.'">'.$post->post_title.'</a></h1>';
						if (strlen($post->post_excerpt) > 0) {
							$promocontent = $post->post_excerpt;
						}
						else {
							$postcontent = str_replace('<ul>', '', $post->post_content);
							$postcontent = str_replace('</ul>', '', $postcontent);
							$postcontent = str_replace('<li>', '', $postcontent);
							$postcontent = str_replace('</li>', '', $postcontent);
							$postcontent = str_replace('<p>', '', $postcontent);
							$postcontent = str_replace("</p>", '', $postcontent);
							$postcontent = str_replace('<span>', '', $postcontent);
							$postcontent = str_replace('</span>', '', $postcontent);
							$postcontent = substr($postcontent, 0, 200);
						}
						$content .= '<h2><span id="PC'.$i.'">'.$promocontent.'</span></h2>';
						$content .= '</div>';
						$content .= '</div>';
					
						$promo_titles[$i] = $post->post_title;
					$i++;
					
					 } */
					 
					 echo $content;
}


// Function name:
//  - get_promo_buttons
// Description:
//  - prints the promo buttons
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for promo buttons

function get_promo_buttons() {
	
	//$promoposts = get_pages('hierarchical=0&meta_key=article_type&meta_value=promo');
	
	include(get_absolute_url(get_bloginfo('stylesheet_directory').'/promos.php'));
	//$promo_buttons = array();	
	asort($promos_order); 
	
	$i = 1;
	foreach($promos_order as $key=>$value) {
   //$promo_buttons[$i]= get_promo_images($key, $i);
   
   echo '<span></span><a id="PButton'.$i.'" href="#" class="PromoButton';
		if ($PromoNr == 1) {
		echo '_on';	
		}					 
		echo '" onclick="switchPromo('.$i.'); return false;"><span style="background: url('.$promos_picture1[$key].') no-repeat center center;"></span></a>';
   
   $i++;
  }
	
	/*
	$i = 1;
	
	
	
	foreach($promoposts as $post) {
   $promo_buttons[$i] = get_one_image($post->ID, 0, 'thumbnail');
   $i++;
   }
   				
   $promoposts = get_posts('meta_key=article_type&meta_value=promo');
				
	foreach($promoposts as $post) {
   $promo_buttons[$i] = get_one_image($post->ID, 0, 'thumbnail');
   $i++;
   } 	
	
 for ($PromoNr = 1 ; $PromoNr < $i ; $PromoNr++) {
	echo '<span></span><a id="PButton'.$PromoNr.'" href="#" class="PromoButton';
	if ($PromoNr == 1) {
	echo '_on';	
	}					 
	echo '" onclick="switchPromo('.$PromoNr.'); return false;"><span style="background: url('.$promo_buttons[$PromoNr].') no-repeat center center;"></span></a>';
}*/
}

// Function name:
//  - get_homepage_articles
// Description:
//  - prints the homepage articles boxes
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for homepage articles

function get_homepage_articles() {
		
		include(get_absolute_url(get_bloginfo('stylesheet_directory').'/homepage_config.php'));
		if ($homepage_articles_auto == 'true') {
				
				 
				 $lastposts = get_posts('meta_key=homepage&meta_value=yes');
				 foreach($lastposts as $post) {

$content .= '
				 <div class="HomepageBox">
				 <h3><a href="'.get_permalink($post->ID).'">'.$post->post_title.'</a></h3>
				 <div class=HomepageBoxThumbnail>
				 <div class=HomepageBoxThumbnailContainer>
				 <a href="'.get_permalink($post->ID).'"><span style="background: url('.get_one_image($post->ID, 0, 'medium').') center center no-repeat;"></span></a>
				 </div>
				 </div>
				 <div class="HomepageBoxThumbnailBottom"><div class="HomepageBoxThumbnailBottomContainer"></div></div>
				 <p>'.substr($post->post_content, 0, 270).'</p>
				 
				 <a class="Button" href="'.get_permalink($post->ID).'"><span>read more</span></a>
				 </div>';
				} 


					
				 $lastposts = get_pages('hierarchical=0&meta_key=homepage&meta_value=yes');
				 foreach($lastposts as $post) {
				 		
				 
$content .= '				
				 <div class="HomepageBox">
				 <h3><a href="'.get_permalink($post->ID).'">'.$post->post_title.'</a></h3>
				 <div class=HomepageBoxThumbnail>
				 <div class=HomepageBoxThumbnailContainer>
				 <a href="'.get_permalink($post->ID).'"><span style="background: url('.get_one_image($post->ID, 0, 'medium').') center center no-repeat;"></span></a>
				 </div>
				 </div>
				 <div class="HomepageBoxThumbnailBottom"><div class="HomepageBoxThumbnailBottomContainer"></div></div>
				 <p>'.substr($post->post_content, 0, 270).'</p>
				 
				 <a class="Button" href="'.get_permalink($post->ID).'"><span>read more</span></a>
				 </div>';
				 
				 }
			}
			else {
				 include(get_absolute_url(get_bloginfo('stylesheet_directory').'/homepage_articles.php'));
				 
				 foreach($articles_name as $key=>$value) {
				 
				 $content .= '				
				 <div class="HomepageBox">
				 <h3><a href="'.$articles_link[$key].'" target="'.$articles_target[$key].'">'.$value.'</a></h3>
				 <div class=HomepageBoxThumbnail>
				 <div class=HomepageBoxThumbnailContainer>
				 <a href="'.$articles_link[$key].'"><span style="background: url('.$articles_picture[$key].') center center no-repeat;"></span></a>
				 </div>
				 </div>
				 <div class="HomepageBoxThumbnailBottom"><div class="HomepageBoxThumbnailBottomContainer"></div></div>
				 <p>'.$articles_text[$key].'</p>
				 
				 <a class="Button" href="'.$articles_link[$key].'"><span>read more</span></a>
				 </div>';
				 
				 }				
				
			}				 
				 echo $content;
}


 
// Function name:
//  - print_fontsize_selector
// Description:
//  - prints the font size selector buttons
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for font size selector

function print_fontsize_selector() {
	  echo '
	    <span class=FontSize>
    	<span>Change font size</span>
    	<a href="#" class="BCLink firstdepth" onclick="ChangeFont(\'default\'); return false;" title="Reset to default"><span>A</span></a>
    	<a href="#" class="BCLink" onclick="ChangeFont(\'decrease\'); return false;" title="Decrease font size"><span>A-</span></a>
    	<a href="#" class="BCLink lastdepth" onclick="ChangeFont(\'increase\'); return false;" title="Increase font size"><span>A+</span></a>
    	</span>';
}

// Function name:
//  - get_right_categories
// Description:
//  - gets and prints the sidebar categories menu
// Parameters:
// 	- no parameter
// Returns:
//  - echoes the HTML code for sidebar categories menu

function get_right_categories() {
		
	if (is_page()) {
	the_post();
	$actualpage_id = get_the_ID();
	$ordered_children = get_ordered_sections($actualpage_id, 1);
	
		if (count($ordered_children) == 0) {
	
			$parent = get_page($actualpage_id);
			$page_id = $parent->post_parent;
			if ($page_id != 0) {
			$ordered_children = get_ordered_sections($page_id, 1);
			}
		}

	
	}
	else {
	
	$cat_name = single_cat_title($prefix = '', $display = false );
	$actual_cat_id = get_cat_ID($cat_name);
	
	$ordered_children = get_ordered_sections($actual_cat_id, 1);

	if (count($ordered_children) == 0) {
		
		$category = get_the_category();
		$cat_id = $category[0]->category_parent;
		if ($cat_id != 0) {
		$ordered_children = get_ordered_sections($cat_id, 1);
	}

	}
	
	
	
	if (is_post && !is_category()) {
		$post_id = get_the_ID();
		$category = get_the_category($post_id);
		$cat_id = $category[0]->cat_ID;
		
		$ordered_children = get_ordered_sections($cat_id, 1);
		
		if (count($ordered_children) == 0) {
		
		$cat_id = $category[0]->category_parent;
		
		if ($cat_id != 0) {
		
		$ordered_children = get_ordered_sections($cat_id, 1);
		$actual_cat_id = $cat_id;
		}
	}
}	

		
	}
	
	
	
	
	
	if(count($ordered_children) > 0) {

	$page_content = '<span class="CategoriesTitle">From this category</span>';
	$page_content .= '<span class="CategoriesBackground">';
	$page_content .= '<ul class=CategoriesContent>';
	$page_content .= '<li class="firstli"></li>';
	$i = 1;
	foreach($ordered_children as $child) {
				
	$section_type = substr($child, 0, 1);
	$section_id = intval(substr($child, 1));
		
	if ($section_type == 'a') { 
	$_page = get_page($section_id);
	$section_title = $_page->post_title;
	$section_link = get_page_link($section_id);
	}
			
	if ($section_type == 'c') { 
	$_category = get_category($section_id);
	$section_title = $_category->cat_name;
	$section_link = get_category_link($section_id);		
	}
			
	if ($section_type == 'p') { 
	$_posts = get_post($section_id);
	$section_title = $_posts->post_title;
	$section_link = get_page_link($section_id);		
	}			

	$page_content .='<li';

	if ($section_id == $actualpage_id || ($section_id == $actual_cat_id && is_category()) || $section_id == $post_id) {
	$page_content .= ' class="current-cat"';
	}
	$page_content .='><a class="CategoriesLink ';
	
	if (count($ordered_children) == $i) {
	$page_content .= ' last';	
	}
	$page_content .= ' " href="'.$section_link.'">'.$section_title.'</a></li>';
	$i++;
	}
	$page_content .= '<li class="lastli"></li>';	
	$page_content .= '</ul>';
	
	$page_content .= '</span>';

	echo $page_content;	
	
	}
}

function getOS($userAgent) {
  // Create list of operating systems with operating system name as array key 
	$oses = array (
		'Windows 3.11' => 'Win16',
		'Windows 95' => '(Windows 95)|(Win95)|(Windows_95)', // Use regular expressions as value to identify operating system
		'Windows 98' => '(Windows 98)|(Win98)',
		'Windows 2000' => '(Windows NT 5.0)|(Windows 2000)',
		'Windows XP' => '(Windows NT 5.1)|(Windows XP)',
		'Windows 2003' => '(Windows NT 5.2)',
		'Windows NT 4.0' => '(Windows NT 4.0)|(WinNT4.0)|(WinNT)|(Windows NT)',
		'Windows ME' => 'Windows ME',
		'Open BSD'=>'OpenBSD',
		'Sun OS'=>'SunOS',
		'Linux'=>'(Linux)|(X11)',
		'Macintosh'=>'(Mac_PowerPC)|(Macintosh)',
		'QNX'=>'QNX',
		'BeOS'=>'BeOS',
		'OS/2'=>'OS/2',
		'Search Bot'=>'(nuhk)|(Googlebot)|(Yammybot)|(Openbot)|(Slurp/cat)|(msnbot)|(ia_archiver)'
	);

	foreach($oses as $os=>$pattern){ // Loop through $oses array
    // Use regular expressions to check operating system type
		if(eregi($pattern, $userAgent)) { // Check if a value in $oses array matches current user agent.
			return $os; // Operating system was matched so return $oses key
		}
	}
	return 'Unknown'; // Cannot find operating system so return Unknown
}


?>